/*
 * WorldEdit, a Minecraft world manipulation toolkit
 * Copyright (C) sk89q <http://www.sk89q.com>
 * Copyright (C) WorldEdit team and contributors
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

package com.sk89q.worldedit.blocks.type;

import java.lang.reflect.Field;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.annotation.Nullable;

/**
 * Stores a list of common Block String IDs.
 */
public class BlockTypes {

    private BlockTypes() {
    }

    public static final BlockType ACACIA_BARK = new BlockType("minecraft:acacia_bark");
    public static final BlockType ACACIA_BUTTON = new BlockType("minecraft:acacia_button");
    public static final BlockType ACACIA_DOOR = new BlockType("minecraft:acacia_door");
    public static final BlockType ACACIA_FENCE = new BlockType("minecraft:acacia_fence");
    public static final BlockType ACACIA_FENCE_GATE = new BlockType("minecraft:acacia_fence_gate");
    public static final BlockType ACACIA_LEAVES = new BlockType("minecraft:acacia_leaves");
    public static final BlockType ACACIA_LOG = new BlockType("minecraft:acacia_log");
    public static final BlockType ACACIA_PLANKS = new BlockType("minecraft:acacia_planks");
    public static final BlockType ACACIA_PRESSURE_PLATE = new BlockType("minecraft:acacia_pressure_plate");
    public static final BlockType ACACIA_SAPLING = new BlockType("minecraft:acacia_sapling");
    public static final BlockType ACACIA_SLAB = new BlockType("minecraft:acacia_slab");
    public static final BlockType ACACIA_STAIRS = new BlockType("minecraft:acacia_stairs");
    public static final BlockType ACACIA_TRAPDOOR = new BlockType("minecraft:acacia_trapdoor");
    public static final BlockType ACTIVATOR_RAIL = new BlockType("minecraft:activator_rail");
    public static final BlockType AIR = new BlockType("minecraft:air");
    public static final BlockType ALLIUM = new BlockType("minecraft:allium");
    public static final BlockType ANDESITE = new BlockType("minecraft:andesite");
    public static final BlockType ANVIL = new BlockType("minecraft:anvil");
    public static final BlockType ATTACHED_MELON_STEM = new BlockType("minecraft:attached_melon_stem");
    public static final BlockType ATTACHED_PUMPKIN_STEM = new BlockType("minecraft:attached_pumpkin_stem");
    public static final BlockType AZURE_BLUET = new BlockType("minecraft:azure_bluet");
    public static final BlockType BARRIER = new BlockType("minecraft:barrier");
    public static final BlockType BEACON = new BlockType("minecraft:beacon");
    public static final BlockType BEDROCK = new BlockType("minecraft:bedrock");
    public static final BlockType BEETROOTS = new BlockType("minecraft:beetroots");
    public static final BlockType BIRCH_BARK = new BlockType("minecraft:birch_bark");
    public static final BlockType BIRCH_BUTTON = new BlockType("minecraft:birch_button");
    public static final BlockType BIRCH_DOOR = new BlockType("minecraft:birch_door");
    public static final BlockType BIRCH_FENCE = new BlockType("minecraft:birch_fence");
    public static final BlockType BIRCH_FENCE_GATE = new BlockType("minecraft:birch_fence_gate");
    public static final BlockType BIRCH_LEAVES = new BlockType("minecraft:birch_leaves");
    public static final BlockType BIRCH_LOG = new BlockType("minecraft:birch_log");
    public static final BlockType BIRCH_PLANKS = new BlockType("minecraft:birch_planks");
    public static final BlockType BIRCH_PRESSURE_PLATE = new BlockType("minecraft:birch_pressure_plate");
    public static final BlockType BIRCH_SAPLING = new BlockType("minecraft:birch_sapling");
    public static final BlockType BIRCH_SLAB = new BlockType("minecraft:birch_slab");
    public static final BlockType BIRCH_STAIRS = new BlockType("minecraft:birch_stairs");
    public static final BlockType BIRCH_TRAPDOOR = new BlockType("minecraft:birch_trapdoor");
    public static final BlockType BLACK_BANNER = new BlockType("minecraft:black_banner");
    public static final BlockType BLACK_BED = new BlockType("minecraft:black_bed");
    public static final BlockType BLACK_CARPET = new BlockType("minecraft:black_carpet");
    public static final BlockType BLACK_CONCRETE = new BlockType("minecraft:black_concrete");
    public static final BlockType BLACK_CONCRETE_POWDER = new BlockType("minecraft:black_concrete_powder");
    public static final BlockType BLACK_GLAZED_TERRACOTTA = new BlockType("minecraft:black_glazed_terracotta");
    public static final BlockType BLACK_SHULKER_BOX = new BlockType("minecraft:black_shulker_box");
    public static final BlockType BLACK_STAINED_GLASS = new BlockType("minecraft:black_stained_glass");
    public static final BlockType BLACK_STAINED_GLASS_PANE = new BlockType("minecraft:black_stained_glass_pane");
    public static final BlockType BLACK_TERRACOTTA = new BlockType("minecraft:black_terracotta");
    public static final BlockType BLACK_WALL_BANNER = new BlockType("minecraft:black_wall_banner");
    public static final BlockType BLACK_WOOL = new BlockType("minecraft:black_wool");
    public static final BlockType BLUE_BANNER = new BlockType("minecraft:blue_banner");
    public static final BlockType BLUE_BED = new BlockType("minecraft:blue_bed");
    public static final BlockType BLUE_CARPET = new BlockType("minecraft:blue_carpet");
    public static final BlockType BLUE_CONCRETE = new BlockType("minecraft:blue_concrete");
    public static final BlockType BLUE_CONCRETE_POWDER = new BlockType("minecraft:blue_concrete_powder");
    public static final BlockType BLUE_GLAZED_TERRACOTTA = new BlockType("minecraft:blue_glazed_terracotta");
    public static final BlockType BLUE_ICE = new BlockType("minecraft:blue_ice");
    public static final BlockType BLUE_ORCHID = new BlockType("minecraft:blue_orchid");
    public static final BlockType BLUE_SHULKER_BOX = new BlockType("minecraft:blue_shulker_box");
    public static final BlockType BLUE_STAINED_GLASS = new BlockType("minecraft:blue_stained_glass");
    public static final BlockType BLUE_STAINED_GLASS_PANE = new BlockType("minecraft:blue_stained_glass_pane");
    public static final BlockType BLUE_TERRACOTTA = new BlockType("minecraft:blue_terracotta");
    public static final BlockType BLUE_WALL_BANNER = new BlockType("minecraft:blue_wall_banner");
    public static final BlockType BLUE_WOOL = new BlockType("minecraft:blue_wool");
    public static final BlockType BONE_BLOCK = new BlockType("minecraft:bone_block");
    public static final BlockType BOOKSHELF = new BlockType("minecraft:bookshelf");
    public static final BlockType BRAIN_CORAL = new BlockType("minecraft:brain_coral");
    public static final BlockType BRAIN_CORAL_BLOCK = new BlockType("minecraft:brain_coral_block");
    public static final BlockType BRAIN_CORAL_FAN = new BlockType("minecraft:brain_coral_fan");
    public static final BlockType BREWING_STAND = new BlockType("minecraft:brewing_stand");
    public static final BlockType BRICK_SLAB = new BlockType("minecraft:brick_slab");
    public static final BlockType BRICK_STAIRS = new BlockType("minecraft:brick_stairs");
    public static final BlockType BRICKS = new BlockType("minecraft:bricks");
    public static final BlockType BROWN_BANNER = new BlockType("minecraft:brown_banner");
    public static final BlockType BROWN_BED = new BlockType("minecraft:brown_bed");
    public static final BlockType BROWN_CARPET = new BlockType("minecraft:brown_carpet");
    public static final BlockType BROWN_CONCRETE = new BlockType("minecraft:brown_concrete");
    public static final BlockType BROWN_CONCRETE_POWDER = new BlockType("minecraft:brown_concrete_powder");
    public static final BlockType BROWN_GLAZED_TERRACOTTA = new BlockType("minecraft:brown_glazed_terracotta");
    public static final BlockType BROWN_MUSHROOM = new BlockType("minecraft:brown_mushroom");
    public static final BlockType BROWN_MUSHROOM_BLOCK = new BlockType("minecraft:brown_mushroom_block");
    public static final BlockType BROWN_SHULKER_BOX = new BlockType("minecraft:brown_shulker_box");
    public static final BlockType BROWN_STAINED_GLASS = new BlockType("minecraft:brown_stained_glass");
    public static final BlockType BROWN_STAINED_GLASS_PANE = new BlockType("minecraft:brown_stained_glass_pane");
    public static final BlockType BROWN_TERRACOTTA = new BlockType("minecraft:brown_terracotta");
    public static final BlockType BROWN_WALL_BANNER = new BlockType("minecraft:brown_wall_banner");
    public static final BlockType BROWN_WOOL = new BlockType("minecraft:brown_wool");
    public static final BlockType BUBBLE_COLUMN = new BlockType("minecraft:bubble_column");
    public static final BlockType BUBBLE_CORAL = new BlockType("minecraft:bubble_coral");
    public static final BlockType BUBBLE_CORAL_BLOCK = new BlockType("minecraft:bubble_coral_block");
    public static final BlockType BUBBLE_CORAL_FAN = new BlockType("minecraft:bubble_coral_fan");
    public static final BlockType CACTUS = new BlockType("minecraft:cactus");
    public static final BlockType CAKE = new BlockType("minecraft:cake");
    public static final BlockType CARROTS = new BlockType("minecraft:carrots");
    public static final BlockType CARVED_PUMPKIN = new BlockType("minecraft:carved_pumpkin");
    public static final BlockType CAULDRON = new BlockType("minecraft:cauldron");
    public static final BlockType CAVE_AIR = new BlockType("minecraft:cave_air");
    public static final BlockType CHAIN_COMMAND_BLOCK = new BlockType("minecraft:chain_command_block");
    public static final BlockType CHEST = new BlockType("minecraft:chest");
    public static final BlockType CHIPPED_ANVIL = new BlockType("minecraft:chipped_anvil");
    public static final BlockType CHISELED_QUARTZ_BLOCK = new BlockType("minecraft:chiseled_quartz_block");
    public static final BlockType CHISELED_RED_SANDSTONE = new BlockType("minecraft:chiseled_red_sandstone");
    public static final BlockType CHISELED_SANDSTONE = new BlockType("minecraft:chiseled_sandstone");
    public static final BlockType CHISELED_STONE_BRICKS = new BlockType("minecraft:chiseled_stone_bricks");
    public static final BlockType CHORUS_FLOWER = new BlockType("minecraft:chorus_flower");
    public static final BlockType CHORUS_PLANT = new BlockType("minecraft:chorus_plant");
    public static final BlockType CLAY = new BlockType("minecraft:clay");
    public static final BlockType COAL_BLOCK = new BlockType("minecraft:coal_block");
    public static final BlockType COAL_ORE = new BlockType("minecraft:coal_ore");
    public static final BlockType COARSE_DIRT = new BlockType("minecraft:coarse_dirt");
    public static final BlockType COBBLESTONE = new BlockType("minecraft:cobblestone");
    public static final BlockType COBBLESTONE_SLAB = new BlockType("minecraft:cobblestone_slab");
    public static final BlockType COBBLESTONE_STAIRS = new BlockType("minecraft:cobblestone_stairs");
    public static final BlockType COBBLESTONE_WALL = new BlockType("minecraft:cobblestone_wall");
    public static final BlockType COBWEB = new BlockType("minecraft:cobweb");
    public static final BlockType COCOA = new BlockType("minecraft:cocoa");
    public static final BlockType COMMAND_BLOCK = new BlockType("minecraft:command_block");
    public static final BlockType COMPARATOR = new BlockType("minecraft:comparator");
    public static final BlockType CONDUIT = new BlockType("minecraft:conduit");
    public static final BlockType CRACKED_STONE_BRICKS = new BlockType("minecraft:cracked_stone_bricks");
    public static final BlockType CRAFTING_TABLE = new BlockType("minecraft:crafting_table");
    public static final BlockType CREEPER_HEAD = new BlockType("minecraft:creeper_head");
    public static final BlockType CREEPER_WALL_HEAD = new BlockType("minecraft:creeper_wall_head");
    public static final BlockType CUT_RED_SANDSTONE = new BlockType("minecraft:cut_red_sandstone");
    public static final BlockType CUT_SANDSTONE = new BlockType("minecraft:cut_sandstone");
    public static final BlockType CYAN_BANNER = new BlockType("minecraft:cyan_banner");
    public static final BlockType CYAN_BED = new BlockType("minecraft:cyan_bed");
    public static final BlockType CYAN_CARPET = new BlockType("minecraft:cyan_carpet");
    public static final BlockType CYAN_CONCRETE = new BlockType("minecraft:cyan_concrete");
    public static final BlockType CYAN_CONCRETE_POWDER = new BlockType("minecraft:cyan_concrete_powder");
    public static final BlockType CYAN_GLAZED_TERRACOTTA = new BlockType("minecraft:cyan_glazed_terracotta");
    public static final BlockType CYAN_SHULKER_BOX = new BlockType("minecraft:cyan_shulker_box");
    public static final BlockType CYAN_STAINED_GLASS = new BlockType("minecraft:cyan_stained_glass");
    public static final BlockType CYAN_STAINED_GLASS_PANE = new BlockType("minecraft:cyan_stained_glass_pane");
    public static final BlockType CYAN_TERRACOTTA = new BlockType("minecraft:cyan_terracotta");
    public static final BlockType CYAN_WALL_BANNER = new BlockType("minecraft:cyan_wall_banner");
    public static final BlockType CYAN_WOOL = new BlockType("minecraft:cyan_wool");
    public static final BlockType DAMAGED_ANVIL = new BlockType("minecraft:damaged_anvil");
    public static final BlockType DANDELION = new BlockType("minecraft:dandelion");
    public static final BlockType DARK_OAK_BARK = new BlockType("minecraft:dark_oak_bark");
    public static final BlockType DARK_OAK_BUTTON = new BlockType("minecraft:dark_oak_button");
    public static final BlockType DARK_OAK_DOOR = new BlockType("minecraft:dark_oak_door");
    public static final BlockType DARK_OAK_FENCE = new BlockType("minecraft:dark_oak_fence");
    public static final BlockType DARK_OAK_FENCE_GATE = new BlockType("minecraft:dark_oak_fence_gate");
    public static final BlockType DARK_OAK_LEAVES = new BlockType("minecraft:dark_oak_leaves");
    public static final BlockType DARK_OAK_LOG = new BlockType("minecraft:dark_oak_log");
    public static final BlockType DARK_OAK_PLANKS = new BlockType("minecraft:dark_oak_planks");
    public static final BlockType DARK_OAK_PRESSURE_PLATE = new BlockType("minecraft:dark_oak_pressure_plate");
    public static final BlockType DARK_OAK_SAPLING = new BlockType("minecraft:dark_oak_sapling");
    public static final BlockType DARK_OAK_SLAB = new BlockType("minecraft:dark_oak_slab");
    public static final BlockType DARK_OAK_STAIRS = new BlockType("minecraft:dark_oak_stairs");
    public static final BlockType DARK_OAK_TRAPDOOR = new BlockType("minecraft:dark_oak_trapdoor");
    public static final BlockType DARK_PRISMARINE = new BlockType("minecraft:dark_prismarine");
    public static final BlockType DARK_PRISMARINE_SLAB = new BlockType("minecraft:dark_prismarine_slab");
    public static final BlockType DARK_PRISMARINE_STAIRS = new BlockType("minecraft:dark_prismarine_stairs");
    public static final BlockType DAYLIGHT_DETECTOR = new BlockType("minecraft:daylight_detector");
    public static final BlockType DEAD_BRAIN_CORAL_BLOCK = new BlockType("minecraft:dead_brain_coral_block");
    public static final BlockType DEAD_BUBBLE_CORAL_BLOCK = new BlockType("minecraft:dead_bubble_coral_block");
    public static final BlockType DEAD_BUSH = new BlockType("minecraft:dead_bush");
    public static final BlockType DEAD_FIRE_CORAL_BLOCK = new BlockType("minecraft:dead_fire_coral_block");
    public static final BlockType DEAD_HORN_CORAL_BLOCK = new BlockType("minecraft:dead_horn_coral_block");
    public static final BlockType DEAD_TUBE_CORAL_BLOCK = new BlockType("minecraft:dead_tube_coral_block");
    public static final BlockType DETECTOR_RAIL = new BlockType("minecraft:detector_rail");
    public static final BlockType DIAMOND_BLOCK = new BlockType("minecraft:diamond_block");
    public static final BlockType DIAMOND_ORE = new BlockType("minecraft:diamond_ore");
    public static final BlockType DIORITE = new BlockType("minecraft:diorite");
    public static final BlockType DIRT = new BlockType("minecraft:dirt");
    public static final BlockType DISPENSER = new BlockType("minecraft:dispenser");
    public static final BlockType DRAGON_EGG = new BlockType("minecraft:dragon_egg");
    public static final BlockType DRAGON_HEAD = new BlockType("minecraft:dragon_head");
    public static final BlockType DRAGON_WALL_HEAD = new BlockType("minecraft:dragon_wall_head");
    public static final BlockType DRIED_KELP_BLOCK = new BlockType("minecraft:dried_kelp_block");
    public static final BlockType DROPPER = new BlockType("minecraft:dropper");
    public static final BlockType EMERALD_BLOCK = new BlockType("minecraft:emerald_block");
    public static final BlockType EMERALD_ORE = new BlockType("minecraft:emerald_ore");
    public static final BlockType ENCHANTING_TABLE = new BlockType("minecraft:enchanting_table");
    public static final BlockType END_GATEWAY = new BlockType("minecraft:end_gateway");
    public static final BlockType END_PORTAL = new BlockType("minecraft:end_portal");
    public static final BlockType END_PORTAL_FRAME = new BlockType("minecraft:end_portal_frame");
    public static final BlockType END_ROD = new BlockType("minecraft:end_rod");
    public static final BlockType END_STONE = new BlockType("minecraft:end_stone");
    public static final BlockType END_STONE_BRICKS = new BlockType("minecraft:end_stone_bricks");
    public static final BlockType ENDER_CHEST = new BlockType("minecraft:ender_chest");
    public static final BlockType FARMLAND = new BlockType("minecraft:farmland");
    public static final BlockType FERN = new BlockType("minecraft:fern");
    public static final BlockType FIRE = new BlockType("minecraft:fire");
    public static final BlockType FIRE_CORAL = new BlockType("minecraft:fire_coral");
    public static final BlockType FIRE_CORAL_BLOCK = new BlockType("minecraft:fire_coral_block");
    public static final BlockType FIRE_CORAL_FAN = new BlockType("minecraft:fire_coral_fan");
    public static final BlockType FLOWER_POT = new BlockType("minecraft:flower_pot");
    public static final BlockType FROSTED_ICE = new BlockType("minecraft:frosted_ice");
    public static final BlockType FURNACE = new BlockType("minecraft:furnace");
    public static final BlockType GLASS = new BlockType("minecraft:glass");
    public static final BlockType GLASS_PANE = new BlockType("minecraft:glass_pane");
    public static final BlockType GLOWSTONE = new BlockType("minecraft:glowstone");
    public static final BlockType GOLD_BLOCK = new BlockType("minecraft:gold_block");
    public static final BlockType GOLD_ORE = new BlockType("minecraft:gold_ore");
    public static final BlockType GRANITE = new BlockType("minecraft:granite");
    public static final BlockType GRASS = new BlockType("minecraft:grass");
    public static final BlockType GRASS_BLOCK = new BlockType("minecraft:grass_block");
    public static final BlockType GRASS_PATH = new BlockType("minecraft:grass_path");
    public static final BlockType GRAVEL = new BlockType("minecraft:gravel");
    public static final BlockType GRAY_BANNER = new BlockType("minecraft:gray_banner");
    public static final BlockType GRAY_BED = new BlockType("minecraft:gray_bed");
    public static final BlockType GRAY_CARPET = new BlockType("minecraft:gray_carpet");
    public static final BlockType GRAY_CONCRETE = new BlockType("minecraft:gray_concrete");
    public static final BlockType GRAY_CONCRETE_POWDER = new BlockType("minecraft:gray_concrete_powder");
    public static final BlockType GRAY_GLAZED_TERRACOTTA = new BlockType("minecraft:gray_glazed_terracotta");
    public static final BlockType GRAY_SHULKER_BOX = new BlockType("minecraft:gray_shulker_box");
    public static final BlockType GRAY_STAINED_GLASS = new BlockType("minecraft:gray_stained_glass");
    public static final BlockType GRAY_STAINED_GLASS_PANE = new BlockType("minecraft:gray_stained_glass_pane");
    public static final BlockType GRAY_TERRACOTTA = new BlockType("minecraft:gray_terracotta");
    public static final BlockType GRAY_WALL_BANNER = new BlockType("minecraft:gray_wall_banner");
    public static final BlockType GRAY_WOOL = new BlockType("minecraft:gray_wool");
    public static final BlockType GREEN_BANNER = new BlockType("minecraft:green_banner");
    public static final BlockType GREEN_BED = new BlockType("minecraft:green_bed");
    public static final BlockType GREEN_CARPET = new BlockType("minecraft:green_carpet");
    public static final BlockType GREEN_CONCRETE = new BlockType("minecraft:green_concrete");
    public static final BlockType GREEN_CONCRETE_POWDER = new BlockType("minecraft:green_concrete_powder");
    public static final BlockType GREEN_GLAZED_TERRACOTTA = new BlockType("minecraft:green_glazed_terracotta");
    public static final BlockType GREEN_SHULKER_BOX = new BlockType("minecraft:green_shulker_box");
    public static final BlockType GREEN_STAINED_GLASS = new BlockType("minecraft:green_stained_glass");
    public static final BlockType GREEN_STAINED_GLASS_PANE = new BlockType("minecraft:green_stained_glass_pane");
    public static final BlockType GREEN_TERRACOTTA = new BlockType("minecraft:green_terracotta");
    public static final BlockType GREEN_WALL_BANNER = new BlockType("minecraft:green_wall_banner");
    public static final BlockType GREEN_WOOL = new BlockType("minecraft:green_wool");
    public static final BlockType HAY_BLOCK = new BlockType("minecraft:hay_block");
    public static final BlockType HEAVY_WEIGHTED_PRESSURE_PLATE = new BlockType("minecraft:heavy_weighted_pressure_plate");
    public static final BlockType HOPPER = new BlockType("minecraft:hopper");
    public static final BlockType HORN_CORAL = new BlockType("minecraft:horn_coral");
    public static final BlockType HORN_CORAL_BLOCK = new BlockType("minecraft:horn_coral_block");
    public static final BlockType HORN_CORAL_FAN = new BlockType("minecraft:horn_coral_fan");
    public static final BlockType ICE = new BlockType("minecraft:ice");
    public static final BlockType INFESTED_CHISELED_STONE_BRICKS = new BlockType("minecraft:infested_chiseled_stone_bricks");
    public static final BlockType INFESTED_COBBLESTONE = new BlockType("minecraft:infested_cobblestone");
    public static final BlockType INFESTED_CRACKED_STONE_BRICKS = new BlockType("minecraft:infested_cracked_stone_bricks");
    public static final BlockType INFESTED_MOSSY_STONE_BRICKS = new BlockType("minecraft:infested_mossy_stone_bricks");
    public static final BlockType INFESTED_STONE = new BlockType("minecraft:infested_stone");
    public static final BlockType INFESTED_STONE_BRICKS = new BlockType("minecraft:infested_stone_bricks");
    public static final BlockType IRON_BARS = new BlockType("minecraft:iron_bars");
    public static final BlockType IRON_BLOCK = new BlockType("minecraft:iron_block");
    public static final BlockType IRON_DOOR = new BlockType("minecraft:iron_door");
    public static final BlockType IRON_ORE = new BlockType("minecraft:iron_ore");
    public static final BlockType IRON_TRAPDOOR = new BlockType("minecraft:iron_trapdoor");
    public static final BlockType JACK_O_LANTERN = new BlockType("minecraft:jack_o_lantern");
    public static final BlockType JUKEBOX = new BlockType("minecraft:jukebox");
    public static final BlockType JUNGLE_BARK = new BlockType("minecraft:jungle_bark");
    public static final BlockType JUNGLE_BUTTON = new BlockType("minecraft:jungle_button");
    public static final BlockType JUNGLE_DOOR = new BlockType("minecraft:jungle_door");
    public static final BlockType JUNGLE_FENCE = new BlockType("minecraft:jungle_fence");
    public static final BlockType JUNGLE_FENCE_GATE = new BlockType("minecraft:jungle_fence_gate");
    public static final BlockType JUNGLE_LEAVES = new BlockType("minecraft:jungle_leaves");
    public static final BlockType JUNGLE_LOG = new BlockType("minecraft:jungle_log");
    public static final BlockType JUNGLE_PLANKS = new BlockType("minecraft:jungle_planks");
    public static final BlockType JUNGLE_PRESSURE_PLATE = new BlockType("minecraft:jungle_pressure_plate");
    public static final BlockType JUNGLE_SAPLING = new BlockType("minecraft:jungle_sapling");
    public static final BlockType JUNGLE_SLAB = new BlockType("minecraft:jungle_slab");
    public static final BlockType JUNGLE_STAIRS = new BlockType("minecraft:jungle_stairs");
    public static final BlockType JUNGLE_TRAPDOOR = new BlockType("minecraft:jungle_trapdoor");
    public static final BlockType KELP = new BlockType("minecraft:kelp");
    public static final BlockType KELP_PLANT = new BlockType("minecraft:kelp_plant");
    public static final BlockType LADDER = new BlockType("minecraft:ladder");
    public static final BlockType LAPIS_BLOCK = new BlockType("minecraft:lapis_block");
    public static final BlockType LAPIS_ORE = new BlockType("minecraft:lapis_ore");
    public static final BlockType LARGE_FERN = new BlockType("minecraft:large_fern");
    public static final BlockType LAVA = new BlockType("minecraft:lava");
    public static final BlockType LEVER = new BlockType("minecraft:lever");
    public static final BlockType LIGHT_BLUE_BANNER = new BlockType("minecraft:light_blue_banner");
    public static final BlockType LIGHT_BLUE_BED = new BlockType("minecraft:light_blue_bed");
    public static final BlockType LIGHT_BLUE_CARPET = new BlockType("minecraft:light_blue_carpet");
    public static final BlockType LIGHT_BLUE_CONCRETE = new BlockType("minecraft:light_blue_concrete");
    public static final BlockType LIGHT_BLUE_CONCRETE_POWDER = new BlockType("minecraft:light_blue_concrete_powder");
    public static final BlockType LIGHT_BLUE_GLAZED_TERRACOTTA = new BlockType("minecraft:light_blue_glazed_terracotta");
    public static final BlockType LIGHT_BLUE_SHULKER_BOX = new BlockType("minecraft:light_blue_shulker_box");
    public static final BlockType LIGHT_BLUE_STAINED_GLASS = new BlockType("minecraft:light_blue_stained_glass");
    public static final BlockType LIGHT_BLUE_STAINED_GLASS_PANE = new BlockType("minecraft:light_blue_stained_glass_pane");
    public static final BlockType LIGHT_BLUE_TERRACOTTA = new BlockType("minecraft:light_blue_terracotta");
    public static final BlockType LIGHT_BLUE_WALL_BANNER = new BlockType("minecraft:light_blue_wall_banner");
    public static final BlockType LIGHT_BLUE_WOOL = new BlockType("minecraft:light_blue_wool");
    public static final BlockType LIGHT_GRAY_BANNER = new BlockType("minecraft:light_gray_banner");
    public static final BlockType LIGHT_GRAY_BED = new BlockType("minecraft:light_gray_bed");
    public static final BlockType LIGHT_GRAY_CARPET = new BlockType("minecraft:light_gray_carpet");
    public static final BlockType LIGHT_GRAY_CONCRETE = new BlockType("minecraft:light_gray_concrete");
    public static final BlockType LIGHT_GRAY_CONCRETE_POWDER = new BlockType("minecraft:light_gray_concrete_powder");
    public static final BlockType LIGHT_GRAY_GLAZED_TERRACOTTA = new BlockType("minecraft:light_gray_glazed_terracotta");
    public static final BlockType LIGHT_GRAY_SHULKER_BOX = new BlockType("minecraft:light_gray_shulker_box");
    public static final BlockType LIGHT_GRAY_STAINED_GLASS = new BlockType("minecraft:light_gray_stained_glass");
    public static final BlockType LIGHT_GRAY_STAINED_GLASS_PANE = new BlockType("minecraft:light_gray_stained_glass_pane");
    public static final BlockType LIGHT_GRAY_TERRACOTTA = new BlockType("minecraft:light_gray_terracotta");
    public static final BlockType LIGHT_GRAY_WALL_BANNER = new BlockType("minecraft:light_gray_wall_banner");
    public static final BlockType LIGHT_GRAY_WOOL = new BlockType("minecraft:light_gray_wool");
    public static final BlockType LIGHT_WEIGHTED_PRESSURE_PLATE = new BlockType("minecraft:light_weighted_pressure_plate");
    public static final BlockType LILAC = new BlockType("minecraft:lilac");
    public static final BlockType LILY_PAD = new BlockType("minecraft:lily_pad");
    public static final BlockType LIME_BANNER = new BlockType("minecraft:lime_banner");
    public static final BlockType LIME_BED = new BlockType("minecraft:lime_bed");
    public static final BlockType LIME_CARPET = new BlockType("minecraft:lime_carpet");
    public static final BlockType LIME_CONCRETE = new BlockType("minecraft:lime_concrete");
    public static final BlockType LIME_CONCRETE_POWDER = new BlockType("minecraft:lime_concrete_powder");
    public static final BlockType LIME_GLAZED_TERRACOTTA = new BlockType("minecraft:lime_glazed_terracotta");
    public static final BlockType LIME_SHULKER_BOX = new BlockType("minecraft:lime_shulker_box");
    public static final BlockType LIME_STAINED_GLASS = new BlockType("minecraft:lime_stained_glass");
    public static final BlockType LIME_STAINED_GLASS_PANE = new BlockType("minecraft:lime_stained_glass_pane");
    public static final BlockType LIME_TERRACOTTA = new BlockType("minecraft:lime_terracotta");
    public static final BlockType LIME_WALL_BANNER = new BlockType("minecraft:lime_wall_banner");
    public static final BlockType LIME_WOOL = new BlockType("minecraft:lime_wool");
    public static final BlockType MAGENTA_BANNER = new BlockType("minecraft:magenta_banner");
    public static final BlockType MAGENTA_BED = new BlockType("minecraft:magenta_bed");
    public static final BlockType MAGENTA_CARPET = new BlockType("minecraft:magenta_carpet");
    public static final BlockType MAGENTA_CONCRETE = new BlockType("minecraft:magenta_concrete");
    public static final BlockType MAGENTA_CONCRETE_POWDER = new BlockType("minecraft:magenta_concrete_powder");
    public static final BlockType MAGENTA_GLAZED_TERRACOTTA = new BlockType("minecraft:magenta_glazed_terracotta");
    public static final BlockType MAGENTA_SHULKER_BOX = new BlockType("minecraft:magenta_shulker_box");
    public static final BlockType MAGENTA_STAINED_GLASS = new BlockType("minecraft:magenta_stained_glass");
    public static final BlockType MAGENTA_STAINED_GLASS_PANE = new BlockType("minecraft:magenta_stained_glass_pane");
    public static final BlockType MAGENTA_TERRACOTTA = new BlockType("minecraft:magenta_terracotta");
    public static final BlockType MAGENTA_WALL_BANNER = new BlockType("minecraft:magenta_wall_banner");
    public static final BlockType MAGENTA_WOOL = new BlockType("minecraft:magenta_wool");
    public static final BlockType MAGMA_BLOCK = new BlockType("minecraft:magma_block");
    public static final BlockType MELON = new BlockType("minecraft:melon");
    public static final BlockType MELON_STEM = new BlockType("minecraft:melon_stem");
    public static final BlockType MOB_SPAWNER = new BlockType("minecraft:mob_spawner");
    public static final BlockType MOSSY_COBBLESTONE = new BlockType("minecraft:mossy_cobblestone");
    public static final BlockType MOSSY_COBBLESTONE_WALL = new BlockType("minecraft:mossy_cobblestone_wall");
    public static final BlockType MOSSY_STONE_BRICKS = new BlockType("minecraft:mossy_stone_bricks");
    public static final BlockType MOVING_PISTON = new BlockType("minecraft:moving_piston");
    public static final BlockType MUSHROOM_STEM = new BlockType("minecraft:mushroom_stem");
    public static final BlockType MYCELIUM = new BlockType("minecraft:mycelium");
    public static final BlockType NETHER_BRICK_FENCE = new BlockType("minecraft:nether_brick_fence");
    public static final BlockType NETHER_BRICK_SLAB = new BlockType("minecraft:nether_brick_slab");
    public static final BlockType NETHER_BRICK_STAIRS = new BlockType("minecraft:nether_brick_stairs");
    public static final BlockType NETHER_BRICKS = new BlockType("minecraft:nether_bricks");
    public static final BlockType NETHER_QUARTZ_ORE = new BlockType("minecraft:nether_quartz_ore");
    public static final BlockType NETHER_WART = new BlockType("minecraft:nether_wart");
    public static final BlockType NETHER_WART_BLOCK = new BlockType("minecraft:nether_wart_block");
    public static final BlockType NETHERRACK = new BlockType("minecraft:netherrack");
    public static final BlockType NOTE_BLOCK = new BlockType("minecraft:note_block");
    public static final BlockType OAK_BARK = new BlockType("minecraft:oak_bark");
    public static final BlockType OAK_BUTTON = new BlockType("minecraft:oak_button");
    public static final BlockType OAK_DOOR = new BlockType("minecraft:oak_door");
    public static final BlockType OAK_FENCE = new BlockType("minecraft:oak_fence");
    public static final BlockType OAK_FENCE_GATE = new BlockType("minecraft:oak_fence_gate");
    public static final BlockType OAK_LEAVES = new BlockType("minecraft:oak_leaves");
    public static final BlockType OAK_LOG = new BlockType("minecraft:oak_log");
    public static final BlockType OAK_PLANKS = new BlockType("minecraft:oak_planks");
    public static final BlockType OAK_PRESSURE_PLATE = new BlockType("minecraft:oak_pressure_plate");
    public static final BlockType OAK_SAPLING = new BlockType("minecraft:oak_sapling");
    public static final BlockType OAK_SLAB = new BlockType("minecraft:oak_slab");
    public static final BlockType OAK_STAIRS = new BlockType("minecraft:oak_stairs");
    public static final BlockType OAK_TRAPDOOR = new BlockType("minecraft:oak_trapdoor");
    public static final BlockType OBSERVER = new BlockType("minecraft:observer");
    public static final BlockType OBSIDIAN = new BlockType("minecraft:obsidian");
    public static final BlockType ORANGE_BANNER = new BlockType("minecraft:orange_banner");
    public static final BlockType ORANGE_BED = new BlockType("minecraft:orange_bed");
    public static final BlockType ORANGE_CARPET = new BlockType("minecraft:orange_carpet");
    public static final BlockType ORANGE_CONCRETE = new BlockType("minecraft:orange_concrete");
    public static final BlockType ORANGE_CONCRETE_POWDER = new BlockType("minecraft:orange_concrete_powder");
    public static final BlockType ORANGE_GLAZED_TERRACOTTA = new BlockType("minecraft:orange_glazed_terracotta");
    public static final BlockType ORANGE_SHULKER_BOX = new BlockType("minecraft:orange_shulker_box");
    public static final BlockType ORANGE_STAINED_GLASS = new BlockType("minecraft:orange_stained_glass");
    public static final BlockType ORANGE_STAINED_GLASS_PANE = new BlockType("minecraft:orange_stained_glass_pane");
    public static final BlockType ORANGE_TERRACOTTA = new BlockType("minecraft:orange_terracotta");
    public static final BlockType ORANGE_TULIP = new BlockType("minecraft:orange_tulip");
    public static final BlockType ORANGE_WALL_BANNER = new BlockType("minecraft:orange_wall_banner");
    public static final BlockType ORANGE_WOOL = new BlockType("minecraft:orange_wool");
    public static final BlockType OXEYE_DAISY = new BlockType("minecraft:oxeye_daisy");
    public static final BlockType PACKED_ICE = new BlockType("minecraft:packed_ice");
    public static final BlockType PEONY = new BlockType("minecraft:peony");
    public static final BlockType PETRIFIED_OAK_SLAB = new BlockType("minecraft:petrified_oak_slab");
    public static final BlockType PINK_BANNER = new BlockType("minecraft:pink_banner");
    public static final BlockType PINK_BED = new BlockType("minecraft:pink_bed");
    public static final BlockType PINK_CARPET = new BlockType("minecraft:pink_carpet");
    public static final BlockType PINK_CONCRETE = new BlockType("minecraft:pink_concrete");
    public static final BlockType PINK_CONCRETE_POWDER = new BlockType("minecraft:pink_concrete_powder");
    public static final BlockType PINK_GLAZED_TERRACOTTA = new BlockType("minecraft:pink_glazed_terracotta");
    public static final BlockType PINK_SHULKER_BOX = new BlockType("minecraft:pink_shulker_box");
    public static final BlockType PINK_STAINED_GLASS = new BlockType("minecraft:pink_stained_glass");
    public static final BlockType PINK_STAINED_GLASS_PANE = new BlockType("minecraft:pink_stained_glass_pane");
    public static final BlockType PINK_TERRACOTTA = new BlockType("minecraft:pink_terracotta");
    public static final BlockType PINK_TULIP = new BlockType("minecraft:pink_tulip");
    public static final BlockType PINK_WALL_BANNER = new BlockType("minecraft:pink_wall_banner");
    public static final BlockType PINK_WOOL = new BlockType("minecraft:pink_wool");
    public static final BlockType PISTON = new BlockType("minecraft:piston");
    public static final BlockType PISTON_HEAD = new BlockType("minecraft:piston_head");
    public static final BlockType PLAYER_HEAD = new BlockType("minecraft:player_head");
    public static final BlockType PLAYER_WALL_HEAD = new BlockType("minecraft:player_wall_head");
    public static final BlockType PODZOL = new BlockType("minecraft:podzol");
    public static final BlockType POLISHED_ANDESITE = new BlockType("minecraft:polished_andesite");
    public static final BlockType POLISHED_DIORITE = new BlockType("minecraft:polished_diorite");
    public static final BlockType POLISHED_GRANITE = new BlockType("minecraft:polished_granite");
    public static final BlockType POPPY = new BlockType("minecraft:poppy");
    public static final BlockType PORTAL = new BlockType("minecraft:portal");
    public static final BlockType POTATOES = new BlockType("minecraft:potatoes");
    public static final BlockType POTTED_ACACIA_SAPLING = new BlockType("minecraft:potted_acacia_sapling");
    public static final BlockType POTTED_ALLIUM = new BlockType("minecraft:potted_allium");
    public static final BlockType POTTED_AZURE_BLUET = new BlockType("minecraft:potted_azure_bluet");
    public static final BlockType POTTED_BIRCH_SAPLING = new BlockType("minecraft:potted_birch_sapling");
    public static final BlockType POTTED_BLUE_ORCHID = new BlockType("minecraft:potted_blue_orchid");
    public static final BlockType POTTED_BROWN_MUSHROOM = new BlockType("minecraft:potted_brown_mushroom");
    public static final BlockType POTTED_CACTUS = new BlockType("minecraft:potted_cactus");
    public static final BlockType POTTED_DANDELION = new BlockType("minecraft:potted_dandelion");
    public static final BlockType POTTED_DARK_OAK_SAPLING = new BlockType("minecraft:potted_dark_oak_sapling");
    public static final BlockType POTTED_DEAD_BUSH = new BlockType("minecraft:potted_dead_bush");
    public static final BlockType POTTED_FERN = new BlockType("minecraft:potted_fern");
    public static final BlockType POTTED_JUNGLE_SAPLING = new BlockType("minecraft:potted_jungle_sapling");
    public static final BlockType POTTED_OAK_SAPLING = new BlockType("minecraft:potted_oak_sapling");
    public static final BlockType POTTED_ORANGE_TULIP = new BlockType("minecraft:potted_orange_tulip");
    public static final BlockType POTTED_OXEYE_DAISY = new BlockType("minecraft:potted_oxeye_daisy");
    public static final BlockType POTTED_PINK_TULIP = new BlockType("minecraft:potted_pink_tulip");
    public static final BlockType POTTED_POPPY = new BlockType("minecraft:potted_poppy");
    public static final BlockType POTTED_RED_MUSHROOM = new BlockType("minecraft:potted_red_mushroom");
    public static final BlockType POTTED_RED_TULIP = new BlockType("minecraft:potted_red_tulip");
    public static final BlockType POTTED_SPRUCE_SAPLING = new BlockType("minecraft:potted_spruce_sapling");
    public static final BlockType POTTED_WHITE_TULIP = new BlockType("minecraft:potted_white_tulip");
    public static final BlockType POWERED_RAIL = new BlockType("minecraft:powered_rail");
    public static final BlockType PRISMARINE = new BlockType("minecraft:prismarine");
    public static final BlockType PRISMARINE_BRICK_SLAB = new BlockType("minecraft:prismarine_brick_slab");
    public static final BlockType PRISMARINE_BRICK_STAIRS = new BlockType("minecraft:prismarine_brick_stairs");
    public static final BlockType PRISMARINE_BRICKS = new BlockType("minecraft:prismarine_bricks");
    public static final BlockType PRISMARINE_SLAB = new BlockType("minecraft:prismarine_slab");
    public static final BlockType PRISMARINE_STAIRS = new BlockType("minecraft:prismarine_stairs");
    public static final BlockType PUMPKIN = new BlockType("minecraft:pumpkin");
    public static final BlockType PUMPKIN_STEM = new BlockType("minecraft:pumpkin_stem");
    public static final BlockType PURPLE_BANNER = new BlockType("minecraft:purple_banner");
    public static final BlockType PURPLE_BED = new BlockType("minecraft:purple_bed");
    public static final BlockType PURPLE_CARPET = new BlockType("minecraft:purple_carpet");
    public static final BlockType PURPLE_CONCRETE = new BlockType("minecraft:purple_concrete");
    public static final BlockType PURPLE_CONCRETE_POWDER = new BlockType("minecraft:purple_concrete_powder");
    public static final BlockType PURPLE_GLAZED_TERRACOTTA = new BlockType("minecraft:purple_glazed_terracotta");
    public static final BlockType PURPLE_SHULKER_BOX = new BlockType("minecraft:purple_shulker_box");
    public static final BlockType PURPLE_STAINED_GLASS = new BlockType("minecraft:purple_stained_glass");
    public static final BlockType PURPLE_STAINED_GLASS_PANE = new BlockType("minecraft:purple_stained_glass_pane");
    public static final BlockType PURPLE_TERRACOTTA = new BlockType("minecraft:purple_terracotta");
    public static final BlockType PURPLE_WALL_BANNER = new BlockType("minecraft:purple_wall_banner");
    public static final BlockType PURPLE_WOOL = new BlockType("minecraft:purple_wool");
    public static final BlockType PURPUR_BLOCK = new BlockType("minecraft:purpur_block");
    public static final BlockType PURPUR_PILLAR = new BlockType("minecraft:purpur_pillar");
    public static final BlockType PURPUR_SLAB = new BlockType("minecraft:purpur_slab");
    public static final BlockType PURPUR_STAIRS = new BlockType("minecraft:purpur_stairs");
    public static final BlockType QUARTZ_BLOCK = new BlockType("minecraft:quartz_block");
    public static final BlockType QUARTZ_PILLAR = new BlockType("minecraft:quartz_pillar");
    public static final BlockType QUARTZ_SLAB = new BlockType("minecraft:quartz_slab");
    public static final BlockType QUARTZ_STAIRS = new BlockType("minecraft:quartz_stairs");
    public static final BlockType RAIL = new BlockType("minecraft:rail");
    public static final BlockType RED_BANNER = new BlockType("minecraft:red_banner");
    public static final BlockType RED_BED = new BlockType("minecraft:red_bed");
    public static final BlockType RED_CARPET = new BlockType("minecraft:red_carpet");
    public static final BlockType RED_CONCRETE = new BlockType("minecraft:red_concrete");
    public static final BlockType RED_CONCRETE_POWDER = new BlockType("minecraft:red_concrete_powder");
    public static final BlockType RED_GLAZED_TERRACOTTA = new BlockType("minecraft:red_glazed_terracotta");
    public static final BlockType RED_MUSHROOM = new BlockType("minecraft:red_mushroom");
    public static final BlockType RED_MUSHROOM_BLOCK = new BlockType("minecraft:red_mushroom_block");
    public static final BlockType RED_NETHER_BRICKS = new BlockType("minecraft:red_nether_bricks");
    public static final BlockType RED_SAND = new BlockType("minecraft:red_sand");
    public static final BlockType RED_SANDSTONE = new BlockType("minecraft:red_sandstone");
    public static final BlockType RED_SANDSTONE_SLAB = new BlockType("minecraft:red_sandstone_slab");
    public static final BlockType RED_SANDSTONE_STAIRS = new BlockType("minecraft:red_sandstone_stairs");
    public static final BlockType RED_SHULKER_BOX = new BlockType("minecraft:red_shulker_box");
    public static final BlockType RED_STAINED_GLASS = new BlockType("minecraft:red_stained_glass");
    public static final BlockType RED_STAINED_GLASS_PANE = new BlockType("minecraft:red_stained_glass_pane");
    public static final BlockType RED_TERRACOTTA = new BlockType("minecraft:red_terracotta");
    public static final BlockType RED_TULIP = new BlockType("minecraft:red_tulip");
    public static final BlockType RED_WALL_BANNER = new BlockType("minecraft:red_wall_banner");
    public static final BlockType RED_WOOL = new BlockType("minecraft:red_wool");
    public static final BlockType REDSTONE_BLOCK = new BlockType("minecraft:redstone_block");
    public static final BlockType REDSTONE_LAMP = new BlockType("minecraft:redstone_lamp");
    public static final BlockType REDSTONE_ORE = new BlockType("minecraft:redstone_ore");
    public static final BlockType REDSTONE_TORCH = new BlockType("minecraft:redstone_torch");
    public static final BlockType REDSTONE_WALL_TORCH = new BlockType("minecraft:redstone_wall_torch");
    public static final BlockType REDSTONE_WIRE = new BlockType("minecraft:redstone_wire");
    public static final BlockType REPEATER = new BlockType("minecraft:repeater");
    public static final BlockType REPEATING_COMMAND_BLOCK = new BlockType("minecraft:repeating_command_block");
    public static final BlockType ROSE_BUSH = new BlockType("minecraft:rose_bush");
    public static final BlockType SAND = new BlockType("minecraft:sand");
    public static final BlockType SANDSTONE = new BlockType("minecraft:sandstone");
    public static final BlockType SANDSTONE_SLAB = new BlockType("minecraft:sandstone_slab");
    public static final BlockType SANDSTONE_STAIRS = new BlockType("minecraft:sandstone_stairs");
    public static final BlockType SEA_LANTERN = new BlockType("minecraft:sea_lantern");
    public static final BlockType SEA_PICKLE = new BlockType("minecraft:sea_pickle");
    public static final BlockType SEAGRASS = new BlockType("minecraft:seagrass");
    public static final BlockType SHULKER_BOX = new BlockType("minecraft:shulker_box");
    public static final BlockType SIGN = new BlockType("minecraft:sign");
    public static final BlockType SKELETON_SKULL = new BlockType("minecraft:skeleton_skull");
    public static final BlockType SKELETON_WALL_SKULL = new BlockType("minecraft:skeleton_wall_skull");
    public static final BlockType SLIME_BLOCK = new BlockType("minecraft:slime_block");
    public static final BlockType SMOOTH_QUARTZ = new BlockType("minecraft:smooth_quartz");
    public static final BlockType SMOOTH_RED_SANDSTONE = new BlockType("minecraft:smooth_red_sandstone");
    public static final BlockType SMOOTH_SANDSTONE = new BlockType("minecraft:smooth_sandstone");
    public static final BlockType SMOOTH_STONE = new BlockType("minecraft:smooth_stone");
    public static final BlockType SNOW = new BlockType("minecraft:snow");
    public static final BlockType SNOW_BLOCK = new BlockType("minecraft:snow_block");
    public static final BlockType SOUL_SAND = new BlockType("minecraft:soul_sand");
    public static final BlockType SPONGE = new BlockType("minecraft:sponge");
    public static final BlockType SPRUCE_BARK = new BlockType("minecraft:spruce_bark");
    public static final BlockType SPRUCE_BUTTON = new BlockType("minecraft:spruce_button");
    public static final BlockType SPRUCE_DOOR = new BlockType("minecraft:spruce_door");
    public static final BlockType SPRUCE_FENCE = new BlockType("minecraft:spruce_fence");
    public static final BlockType SPRUCE_FENCE_GATE = new BlockType("minecraft:spruce_fence_gate");
    public static final BlockType SPRUCE_LEAVES = new BlockType("minecraft:spruce_leaves");
    public static final BlockType SPRUCE_LOG = new BlockType("minecraft:spruce_log");
    public static final BlockType SPRUCE_PLANKS = new BlockType("minecraft:spruce_planks");
    public static final BlockType SPRUCE_PRESSURE_PLATE = new BlockType("minecraft:spruce_pressure_plate");
    public static final BlockType SPRUCE_SAPLING = new BlockType("minecraft:spruce_sapling");
    public static final BlockType SPRUCE_SLAB = new BlockType("minecraft:spruce_slab");
    public static final BlockType SPRUCE_STAIRS = new BlockType("minecraft:spruce_stairs");
    public static final BlockType SPRUCE_TRAPDOOR = new BlockType("minecraft:spruce_trapdoor");
    public static final BlockType STICKY_PISTON = new BlockType("minecraft:sticky_piston");
    public static final BlockType STONE = new BlockType("minecraft:stone");
    public static final BlockType STONE_BRICK_SLAB = new BlockType("minecraft:stone_brick_slab");
    public static final BlockType STONE_BRICK_STAIRS = new BlockType("minecraft:stone_brick_stairs");
    public static final BlockType STONE_BRICKS = new BlockType("minecraft:stone_bricks");
    public static final BlockType STONE_BUTTON = new BlockType("minecraft:stone_button");
    public static final BlockType STONE_PRESSURE_PLATE = new BlockType("minecraft:stone_pressure_plate");
    public static final BlockType STONE_SLAB = new BlockType("minecraft:stone_slab");
    public static final BlockType STRIPPED_ACACIA_LOG = new BlockType("minecraft:stripped_acacia_log");
    public static final BlockType STRIPPED_BIRCH_LOG = new BlockType("minecraft:stripped_birch_log");
    public static final BlockType STRIPPED_DARK_OAK_LOG = new BlockType("minecraft:stripped_dark_oak_log");
    public static final BlockType STRIPPED_JUNGLE_LOG = new BlockType("minecraft:stripped_jungle_log");
    public static final BlockType STRIPPED_OAK_LOG = new BlockType("minecraft:stripped_oak_log");
    public static final BlockType STRIPPED_SPRUCE_LOG = new BlockType("minecraft:stripped_spruce_log");
    public static final BlockType STRUCTURE_BLOCK = new BlockType("minecraft:structure_block");
    public static final BlockType STRUCTURE_VOID = new BlockType("minecraft:structure_void");
    public static final BlockType SUGAR_CANE = new BlockType("minecraft:sugar_cane");
    public static final BlockType SUNFLOWER = new BlockType("minecraft:sunflower");
    public static final BlockType TALL_GRASS = new BlockType("minecraft:tall_grass");
    public static final BlockType TALL_SEAGRASS = new BlockType("minecraft:tall_seagrass");
    public static final BlockType TERRACOTTA = new BlockType("minecraft:terracotta");
    public static final BlockType TNT = new BlockType("minecraft:tnt");
    public static final BlockType TORCH = new BlockType("minecraft:torch");
    public static final BlockType TRAPPED_CHEST = new BlockType("minecraft:trapped_chest");
    public static final BlockType TRIPWIRE = new BlockType("minecraft:tripwire");
    public static final BlockType TRIPWIRE_HOOK = new BlockType("minecraft:tripwire_hook");
    public static final BlockType TUBE_CORAL = new BlockType("minecraft:tube_coral");
    public static final BlockType TUBE_CORAL_BLOCK = new BlockType("minecraft:tube_coral_block");
    public static final BlockType TUBE_CORAL_FAN = new BlockType("minecraft:tube_coral_fan");
    public static final BlockType TURTLE_EGG = new BlockType("minecraft:turtle_egg");
    public static final BlockType VINE = new BlockType("minecraft:vine");
    public static final BlockType VOID_AIR = new BlockType("minecraft:void_air");
    public static final BlockType WALL_SIGN = new BlockType("minecraft:wall_sign");
    public static final BlockType WALL_TORCH = new BlockType("minecraft:wall_torch");
    public static final BlockType WATER = new BlockType("minecraft:water");
    public static final BlockType WET_SPONGE = new BlockType("minecraft:wet_sponge");
    public static final BlockType WHEAT = new BlockType("minecraft:wheat");
    public static final BlockType WHITE_BANNER = new BlockType("minecraft:white_banner");
    public static final BlockType WHITE_BED = new BlockType("minecraft:white_bed");
    public static final BlockType WHITE_CARPET = new BlockType("minecraft:white_carpet");
    public static final BlockType WHITE_CONCRETE = new BlockType("minecraft:white_concrete");
    public static final BlockType WHITE_CONCRETE_POWDER = new BlockType("minecraft:white_concrete_powder");
    public static final BlockType WHITE_GLAZED_TERRACOTTA = new BlockType("minecraft:white_glazed_terracotta");
    public static final BlockType WHITE_SHULKER_BOX = new BlockType("minecraft:white_shulker_box");
    public static final BlockType WHITE_STAINED_GLASS = new BlockType("minecraft:white_stained_glass");
    public static final BlockType WHITE_STAINED_GLASS_PANE = new BlockType("minecraft:white_stained_glass_pane");
    public static final BlockType WHITE_TERRACOTTA = new BlockType("minecraft:white_terracotta");
    public static final BlockType WHITE_TULIP = new BlockType("minecraft:white_tulip");
    public static final BlockType WHITE_WALL_BANNER = new BlockType("minecraft:white_wall_banner");
    public static final BlockType WHITE_WOOL = new BlockType("minecraft:white_wool");
    public static final BlockType WITHER_SKELETON_SKULL = new BlockType("minecraft:wither_skeleton_skull");
    public static final BlockType WITHER_SKELETON_WALL_SKULL = new BlockType("minecraft:wither_skeleton_wall_skull");
    public static final BlockType YELLOW_BANNER = new BlockType("minecraft:yellow_banner");
    public static final BlockType YELLOW_BED = new BlockType("minecraft:yellow_bed");
    public static final BlockType YELLOW_CARPET = new BlockType("minecraft:yellow_carpet");
    public static final BlockType YELLOW_CONCRETE = new BlockType("minecraft:yellow_concrete");
    public static final BlockType YELLOW_CONCRETE_POWDER = new BlockType("minecraft:yellow_concrete_powder");
    public static final BlockType YELLOW_GLAZED_TERRACOTTA = new BlockType("minecraft:yellow_glazed_terracotta");
    public static final BlockType YELLOW_SHULKER_BOX = new BlockType("minecraft:yellow_shulker_box");
    public static final BlockType YELLOW_STAINED_GLASS = new BlockType("minecraft:yellow_stained_glass");
    public static final BlockType YELLOW_STAINED_GLASS_PANE = new BlockType("minecraft:yellow_stained_glass_pane");
    public static final BlockType YELLOW_TERRACOTTA = new BlockType("minecraft:yellow_terracotta");
    public static final BlockType YELLOW_WALL_BANNER = new BlockType("minecraft:yellow_wall_banner");
    public static final BlockType YELLOW_WOOL = new BlockType("minecraft:yellow_wool");
    public static final BlockType ZOMBIE_HEAD = new BlockType("minecraft:zombie_head");
    public static final BlockType ZOMBIE_WALL_HEAD = new BlockType("minecraft:zombie_wall_head");

    private static final Map<String, BlockType> blockMapping = new HashMap<>();

    static {
        for (Field field : BlockTypes.class.getFields()) {
            if (field.getType() == BlockType.class) {
                try {
                    registerBlock((BlockType) field.get(null));
                } catch (IllegalAccessException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public static void registerBlock(BlockType blockType) {
        if (blockMapping.containsKey(blockType.getId()) && !blockType.getId().startsWith("minecraft:")) {
            throw new IllegalArgumentException("Existing block with this ID already registered");
        }

        blockMapping.put(blockType.getId(), blockType);
    }

    @Nullable
    public static BlockType getBlockType(String id) {
        // If it has no namespace, assume minecraft.
        if (id != null && !id.contains(":")) {
            id = "minecraft:" + id;
        }
        return blockMapping.get(id);
    }

    public static Collection<BlockType> values() {
        return blockMapping.values();
    }
}
