/*
 * WorldEdit, a Minecraft world manipulation toolkit
 * Copyright (C) sk89q <http://www.sk89q.com>
 * Copyright (C) WorldEdit team and contributors
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

package com.sk89q.worldedit.blocks.type;

import java.lang.reflect.Field;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.annotation.Nullable;

public class ItemTypes {

    private ItemTypes() {
    }

    public static final ItemType ACACIA_BARK = new ItemType("minecraft:acacia_bark");
    public static final ItemType ACACIA_BOAT = new ItemType("minecraft:acacia_boat");
    public static final ItemType ACACIA_BUTTON = new ItemType("minecraft:acacia_button");
    public static final ItemType ACACIA_FENCE = new ItemType("minecraft:acacia_fence");
    public static final ItemType ACACIA_FENCE_GATE = new ItemType("minecraft:acacia_fence_gate");
    public static final ItemType ACACIA_LEAVES = new ItemType("minecraft:acacia_leaves");
    public static final ItemType ACACIA_LOG = new ItemType("minecraft:acacia_log");
    public static final ItemType ACACIA_PLANKS = new ItemType("minecraft:acacia_planks");
    public static final ItemType ACACIA_PRESSURE_PLATE = new ItemType("minecraft:acacia_pressure_plate");
    public static final ItemType ACACIA_SAPLING = new ItemType("minecraft:acacia_sapling");
    public static final ItemType ACACIA_SLAB = new ItemType("minecraft:acacia_slab");
    public static final ItemType ACACIA_STAIRS = new ItemType("minecraft:acacia_stairs");
    public static final ItemType ACACIA_TRAPDOOR = new ItemType("minecraft:acacia_trapdoor");
    public static final ItemType ACTIVATOR_RAIL = new ItemType("minecraft:activator_rail");
    public static final ItemType AIR = new ItemType("minecraft:air");
    public static final ItemType ALLIUM = new ItemType("minecraft:allium");
    public static final ItemType ANDESITE = new ItemType("minecraft:andesite");
    public static final ItemType ANVIL = new ItemType("minecraft:anvil");
    public static final ItemType APPLE = new ItemType("minecraft:apple");
    public static final ItemType ARMOR_STAND = new ItemType("minecraft:armor_stand");
    public static final ItemType ARROW = new ItemType("minecraft:arrow");
    public static final ItemType AZURE_BLUET = new ItemType("minecraft:azure_bluet");
    public static final ItemType BAKED_POTATO = new ItemType("minecraft:baked_potato");
    public static final ItemType BARRIER = new ItemType("minecraft:barrier");
    public static final ItemType BAT_SPAWN_EGG = new ItemType("minecraft:bat_spawn_egg");
    public static final ItemType BEDROCK = new ItemType("minecraft:bedrock");
    public static final ItemType BEEF = new ItemType("minecraft:beef");
    public static final ItemType BEETROOT = new ItemType("minecraft:beetroot");
    public static final ItemType BEETROOT_SEEDS = new ItemType("minecraft:beetroot_seeds");
    public static final ItemType BEETROOT_SOUP = new ItemType("minecraft:beetroot_soup");
    public static final ItemType BIRCH_BARK = new ItemType("minecraft:birch_bark");
    public static final ItemType BIRCH_BOAT = new ItemType("minecraft:birch_boat");
    public static final ItemType BIRCH_BUTTON = new ItemType("minecraft:birch_button");
    public static final ItemType BIRCH_FENCE = new ItemType("minecraft:birch_fence");
    public static final ItemType BIRCH_FENCE_GATE = new ItemType("minecraft:birch_fence_gate");
    public static final ItemType BIRCH_LEAVES = new ItemType("minecraft:birch_leaves");
    public static final ItemType BIRCH_LOG = new ItemType("minecraft:birch_log");
    public static final ItemType BIRCH_PLANKS = new ItemType("minecraft:birch_planks");
    public static final ItemType BIRCH_PRESSURE_PLATE = new ItemType("minecraft:birch_pressure_plate");
    public static final ItemType BIRCH_SAPLING = new ItemType("minecraft:birch_sapling");
    public static final ItemType BIRCH_SLAB = new ItemType("minecraft:birch_slab");
    public static final ItemType BIRCH_STAIRS = new ItemType("minecraft:birch_stairs");
    public static final ItemType BIRCH_TRAPDOOR = new ItemType("minecraft:birch_trapdoor");
    public static final ItemType BLACK_BANNER = new ItemType("minecraft:black_banner");
    public static final ItemType BLACK_CARPET = new ItemType("minecraft:black_carpet");
    public static final ItemType BLACK_CONCRETE = new ItemType("minecraft:black_concrete");
    public static final ItemType BLACK_CONCRETE_POWDER = new ItemType("minecraft:black_concrete_powder");
    public static final ItemType BLACK_GLAZED_TERRACOTTA = new ItemType("minecraft:black_glazed_terracotta");
    public static final ItemType BLACK_STAINED_GLASS = new ItemType("minecraft:black_stained_glass");
    public static final ItemType BLACK_STAINED_GLASS_PANE = new ItemType("minecraft:black_stained_glass_pane");
    public static final ItemType BLACK_TERRACOTTA = new ItemType("minecraft:black_terracotta");
    public static final ItemType BLACK_WOOL = new ItemType("minecraft:black_wool");
    public static final ItemType BLAZE_POWDER = new ItemType("minecraft:blaze_powder");
    public static final ItemType BLAZE_ROD = new ItemType("minecraft:blaze_rod");
    public static final ItemType BLAZE_SPAWN_EGG = new ItemType("minecraft:blaze_spawn_egg");
    public static final ItemType BLUE_BANNER = new ItemType("minecraft:blue_banner");
    public static final ItemType BLUE_CARPET = new ItemType("minecraft:blue_carpet");
    public static final ItemType BLUE_CONCRETE = new ItemType("minecraft:blue_concrete");
    public static final ItemType BLUE_CONCRETE_POWDER = new ItemType("minecraft:blue_concrete_powder");
    public static final ItemType BLUE_GLAZED_TERRACOTTA = new ItemType("minecraft:blue_glazed_terracotta");
    public static final ItemType BLUE_ICE = new ItemType("minecraft:blue_ice");
    public static final ItemType BLUE_ORCHID = new ItemType("minecraft:blue_orchid");
    public static final ItemType BLUE_STAINED_GLASS = new ItemType("minecraft:blue_stained_glass");
    public static final ItemType BLUE_STAINED_GLASS_PANE = new ItemType("minecraft:blue_stained_glass_pane");
    public static final ItemType BLUE_TERRACOTTA = new ItemType("minecraft:blue_terracotta");
    public static final ItemType BLUE_WOOL = new ItemType("minecraft:blue_wool");
    public static final ItemType BONE = new ItemType("minecraft:bone");
    public static final ItemType BONE_BLOCK = new ItemType("minecraft:bone_block");
    public static final ItemType BONE_MEAL = new ItemType("minecraft:bone_meal");
    public static final ItemType BOOK = new ItemType("minecraft:book");
    public static final ItemType BOOKSHELF = new ItemType("minecraft:bookshelf");
    public static final ItemType BOW = new ItemType("minecraft:bow");
    public static final ItemType BOWL = new ItemType("minecraft:bowl");
    public static final ItemType BRAIN_CORAL = new ItemType("minecraft:brain_coral");
    public static final ItemType BRAIN_CORAL_BLOCK = new ItemType("minecraft:brain_coral_block");
    public static final ItemType BRAIN_CORAL_FAN = new ItemType("minecraft:brain_coral_fan");
    public static final ItemType BREAD = new ItemType("minecraft:bread");
    public static final ItemType BREWING_STAND = new ItemType("minecraft:brewing_stand");
    public static final ItemType BRICK = new ItemType("minecraft:brick");
    public static final ItemType BRICK_SLAB = new ItemType("minecraft:brick_slab");
    public static final ItemType BRICK_STAIRS = new ItemType("minecraft:brick_stairs");
    public static final ItemType BRICKS = new ItemType("minecraft:bricks");
    public static final ItemType BROWN_BANNER = new ItemType("minecraft:brown_banner");
    public static final ItemType BROWN_CARPET = new ItemType("minecraft:brown_carpet");
    public static final ItemType BROWN_CONCRETE = new ItemType("minecraft:brown_concrete");
    public static final ItemType BROWN_CONCRETE_POWDER = new ItemType("minecraft:brown_concrete_powder");
    public static final ItemType BROWN_GLAZED_TERRACOTTA = new ItemType("minecraft:brown_glazed_terracotta");
    public static final ItemType BROWN_MUSHROOM = new ItemType("minecraft:brown_mushroom");
    public static final ItemType BROWN_MUSHROOM_BLOCK = new ItemType("minecraft:brown_mushroom_block");
    public static final ItemType BROWN_STAINED_GLASS = new ItemType("minecraft:brown_stained_glass");
    public static final ItemType BROWN_STAINED_GLASS_PANE = new ItemType("minecraft:brown_stained_glass_pane");
    public static final ItemType BROWN_TERRACOTTA = new ItemType("minecraft:brown_terracotta");
    public static final ItemType BROWN_WOOL = new ItemType("minecraft:brown_wool");
    public static final ItemType BUBBLE_CORAL = new ItemType("minecraft:bubble_coral");
    public static final ItemType BUBBLE_CORAL_BLOCK = new ItemType("minecraft:bubble_coral_block");
    public static final ItemType BUBBLE_CORAL_FAN = new ItemType("minecraft:bubble_coral_fan");
    public static final ItemType BUCKET = new ItemType("minecraft:bucket");
    public static final ItemType CACTUS = new ItemType("minecraft:cactus");
    public static final ItemType CACTUS_GREEN = new ItemType("minecraft:cactus_green");
    public static final ItemType CARROT = new ItemType("minecraft:carrot");
    public static final ItemType CARROT_ON_A_STICK = new ItemType("minecraft:carrot_on_a_stick");
    public static final ItemType CARVED_PUMPKIN = new ItemType("minecraft:carved_pumpkin");
    public static final ItemType CAULDRON = new ItemType("minecraft:cauldron");
    public static final ItemType CAVE_SPIDER_SPAWN_EGG = new ItemType("minecraft:cave_spider_spawn_egg");
    public static final ItemType CHAINMAIL_BOOTS = new ItemType("minecraft:chainmail_boots");
    public static final ItemType CHAINMAIL_CHESTPLATE = new ItemType("minecraft:chainmail_chestplate");
    public static final ItemType CHAINMAIL_HELMET = new ItemType("minecraft:chainmail_helmet");
    public static final ItemType CHAINMAIL_LEGGINGS = new ItemType("minecraft:chainmail_leggings");
    public static final ItemType CHARCOAL = new ItemType("minecraft:charcoal");
    public static final ItemType CHEST = new ItemType("minecraft:chest");
    public static final ItemType CHEST_MINECART = new ItemType("minecraft:chest_minecart");
    public static final ItemType CHICKEN = new ItemType("minecraft:chicken");
    public static final ItemType CHICKEN_SPAWN_EGG = new ItemType("minecraft:chicken_spawn_egg");
    public static final ItemType CHIPPED_ANVIL = new ItemType("minecraft:chipped_anvil");
    public static final ItemType CHISELED_QUARTZ_BLOCK = new ItemType("minecraft:chiseled_quartz_block");
    public static final ItemType CHISELED_RED_SANDSTONE = new ItemType("minecraft:chiseled_red_sandstone");
    public static final ItemType CHISELED_SANDSTONE = new ItemType("minecraft:chiseled_sandstone");
    public static final ItemType CHISELED_STONE_BRICKS = new ItemType("minecraft:chiseled_stone_bricks");
    public static final ItemType CHORUS_FLOWER = new ItemType("minecraft:chorus_flower");
    public static final ItemType CHORUS_FRUIT = new ItemType("minecraft:chorus_fruit");
    public static final ItemType CHORUS_FRUIT_POPPED = new ItemType("minecraft:chorus_fruit_popped");
    public static final ItemType CHORUS_PLANT = new ItemType("minecraft:chorus_plant");
    public static final ItemType CLAY = new ItemType("minecraft:clay");
    public static final ItemType CLAY_BALL = new ItemType("minecraft:clay_ball");
    public static final ItemType CLOCK = new ItemType("minecraft:clock");
    public static final ItemType CLOWNFISH = new ItemType("minecraft:clownfish");
    public static final ItemType CLOWNFISH_BUCKET = new ItemType("minecraft:clownfish_bucket");
    public static final ItemType COAL = new ItemType("minecraft:coal");
    public static final ItemType COAL_BLOCK = new ItemType("minecraft:coal_block");
    public static final ItemType COAL_ORE = new ItemType("minecraft:coal_ore");
    public static final ItemType COARSE_DIRT = new ItemType("minecraft:coarse_dirt");
    public static final ItemType COBBLESTONE = new ItemType("minecraft:cobblestone");
    public static final ItemType COBBLESTONE_SLAB = new ItemType("minecraft:cobblestone_slab");
    public static final ItemType COBBLESTONE_STAIRS = new ItemType("minecraft:cobblestone_stairs");
    public static final ItemType COBBLESTONE_WALL = new ItemType("minecraft:cobblestone_wall");
    public static final ItemType COBWEB = new ItemType("minecraft:cobweb");
    public static final ItemType COCOA_BEANS = new ItemType("minecraft:cocoa_beans");
    public static final ItemType COD = new ItemType("minecraft:cod");
    public static final ItemType COD_BUCKET = new ItemType("minecraft:cod_bucket");
    public static final ItemType COD_SPAWN_EGG = new ItemType("minecraft:cod_spawn_egg");
    public static final ItemType COMMAND_BLOCK_MINECART = new ItemType("minecraft:command_block_minecart");
    public static final ItemType COMPARATOR = new ItemType("minecraft:comparator");
    public static final ItemType COMPASS = new ItemType("minecraft:compass");
    public static final ItemType COOKED_BEEF = new ItemType("minecraft:cooked_beef");
    public static final ItemType COOKED_CHICKEN = new ItemType("minecraft:cooked_chicken");
    public static final ItemType COOKED_COD = new ItemType("minecraft:cooked_cod");
    public static final ItemType COOKED_MUTTON = new ItemType("minecraft:cooked_mutton");
    public static final ItemType COOKED_PORKCHOP = new ItemType("minecraft:cooked_porkchop");
    public static final ItemType COOKED_RABBIT = new ItemType("minecraft:cooked_rabbit");
    public static final ItemType COOKED_SALMON = new ItemType("minecraft:cooked_salmon");
    public static final ItemType COOKIE = new ItemType("minecraft:cookie");
    public static final ItemType COW_SPAWN_EGG = new ItemType("minecraft:cow_spawn_egg");
    public static final ItemType CRACKED_STONE_BRICKS = new ItemType("minecraft:cracked_stone_bricks");
    public static final ItemType CRAFTING_TABLE = new ItemType("minecraft:crafting_table");
    public static final ItemType CREEPER_SPAWN_EGG = new ItemType("minecraft:creeper_spawn_egg");
    public static final ItemType CUT_RED_SANDSTONE = new ItemType("minecraft:cut_red_sandstone");
    public static final ItemType CUT_SANDSTONE = new ItemType("minecraft:cut_sandstone");
    public static final ItemType CYAN_BANNER = new ItemType("minecraft:cyan_banner");
    public static final ItemType CYAN_CARPET = new ItemType("minecraft:cyan_carpet");
    public static final ItemType CYAN_CONCRETE = new ItemType("minecraft:cyan_concrete");
    public static final ItemType CYAN_CONCRETE_POWDER = new ItemType("minecraft:cyan_concrete_powder");
    public static final ItemType CYAN_DYE = new ItemType("minecraft:cyan_dye");
    public static final ItemType CYAN_GLAZED_TERRACOTTA = new ItemType("minecraft:cyan_glazed_terracotta");
    public static final ItemType CYAN_STAINED_GLASS = new ItemType("minecraft:cyan_stained_glass");
    public static final ItemType CYAN_STAINED_GLASS_PANE = new ItemType("minecraft:cyan_stained_glass_pane");
    public static final ItemType CYAN_TERRACOTTA = new ItemType("minecraft:cyan_terracotta");
    public static final ItemType CYAN_WOOL = new ItemType("minecraft:cyan_wool");
    public static final ItemType DAMAGED_ANVIL = new ItemType("minecraft:damaged_anvil");
    public static final ItemType DANDELION = new ItemType("minecraft:dandelion");
    public static final ItemType DANDELION_YELLOW = new ItemType("minecraft:dandelion_yellow");
    public static final ItemType DARK_OAK_BARK = new ItemType("minecraft:dark_oak_bark");
    public static final ItemType DARK_OAK_BOAT = new ItemType("minecraft:dark_oak_boat");
    public static final ItemType DARK_OAK_BUTTON = new ItemType("minecraft:dark_oak_button");
    public static final ItemType DARK_OAK_FENCE = new ItemType("minecraft:dark_oak_fence");
    public static final ItemType DARK_OAK_FENCE_GATE = new ItemType("minecraft:dark_oak_fence_gate");
    public static final ItemType DARK_OAK_LEAVES = new ItemType("minecraft:dark_oak_leaves");
    public static final ItemType DARK_OAK_LOG = new ItemType("minecraft:dark_oak_log");
    public static final ItemType DARK_OAK_PLANKS = new ItemType("minecraft:dark_oak_planks");
    public static final ItemType DARK_OAK_PRESSURE_PLATE = new ItemType("minecraft:dark_oak_pressure_plate");
    public static final ItemType DARK_OAK_SAPLING = new ItemType("minecraft:dark_oak_sapling");
    public static final ItemType DARK_OAK_SLAB = new ItemType("minecraft:dark_oak_slab");
    public static final ItemType DARK_OAK_STAIRS = new ItemType("minecraft:dark_oak_stairs");
    public static final ItemType DARK_OAK_TRAPDOOR = new ItemType("minecraft:dark_oak_trapdoor");
    public static final ItemType DARK_PRISMARINE = new ItemType("minecraft:dark_prismarine");
    public static final ItemType DARK_PRISMARINE_SLAB = new ItemType("minecraft:dark_prismarine_slab");
    public static final ItemType DARK_PRISMARINE_STAIRS = new ItemType("minecraft:dark_prismarine_stairs");
    public static final ItemType DAYLIGHT_DETECTOR = new ItemType("minecraft:daylight_detector");
    public static final ItemType DEAD_BRAIN_CORAL_BLOCK = new ItemType("minecraft:dead_brain_coral_block");
    public static final ItemType DEAD_BUBBLE_CORAL_BLOCK = new ItemType("minecraft:dead_bubble_coral_block");
    public static final ItemType DEAD_BUSH = new ItemType("minecraft:dead_bush");
    public static final ItemType DEAD_FIRE_CORAL_BLOCK = new ItemType("minecraft:dead_fire_coral_block");
    public static final ItemType DEAD_HORN_CORAL_BLOCK = new ItemType("minecraft:dead_horn_coral_block");
    public static final ItemType DEAD_TUBE_CORAL_BLOCK = new ItemType("minecraft:dead_tube_coral_block");
    public static final ItemType DEBUG_STICK = new ItemType("minecraft:debug_stick");
    public static final ItemType DETECTOR_RAIL = new ItemType("minecraft:detector_rail");
    public static final ItemType DIAMOND = new ItemType("minecraft:diamond");
    public static final ItemType DIAMOND_AXE = new ItemType("minecraft:diamond_axe");
    public static final ItemType DIAMOND_BLOCK = new ItemType("minecraft:diamond_block");
    public static final ItemType DIAMOND_BOOTS = new ItemType("minecraft:diamond_boots");
    public static final ItemType DIAMOND_CHESTPLATE = new ItemType("minecraft:diamond_chestplate");
    public static final ItemType DIAMOND_HELMET = new ItemType("minecraft:diamond_helmet");
    public static final ItemType DIAMOND_HOE = new ItemType("minecraft:diamond_hoe");
    public static final ItemType DIAMOND_HORSE_ARMOR = new ItemType("minecraft:diamond_horse_armor");
    public static final ItemType DIAMOND_LEGGINGS = new ItemType("minecraft:diamond_leggings");
    public static final ItemType DIAMOND_ORE = new ItemType("minecraft:diamond_ore");
    public static final ItemType DIAMOND_PICKAXE = new ItemType("minecraft:diamond_pickaxe");
    public static final ItemType DIAMOND_SHOVEL = new ItemType("minecraft:diamond_shovel");
    public static final ItemType DIAMOND_SWORD = new ItemType("minecraft:diamond_sword");
    public static final ItemType DIORITE = new ItemType("minecraft:diorite");
    public static final ItemType DIRT = new ItemType("minecraft:dirt");
    public static final ItemType DISPENSER = new ItemType("minecraft:dispenser");
    public static final ItemType DOLPHIN_SPAWN_EGG = new ItemType("minecraft:dolphin_spawn_egg");
    public static final ItemType DONKEY_SPAWN_EGG = new ItemType("minecraft:donkey_spawn_egg");
    public static final ItemType DRAGON_BREATH = new ItemType("minecraft:dragon_breath");
    public static final ItemType DRIED_KELP = new ItemType("minecraft:dried_kelp");
    public static final ItemType DRIED_KELP_BLOCK = new ItemType("minecraft:dried_kelp_block");
    public static final ItemType DROPPER = new ItemType("minecraft:dropper");
    public static final ItemType DROWNED_SPAWN_EGG = new ItemType("minecraft:drowned_spawn_egg");
    public static final ItemType EGG = new ItemType("minecraft:egg");
    public static final ItemType ELDER_GUARDIAN_SPAWN_EGG = new ItemType("minecraft:elder_guardian_spawn_egg");
    public static final ItemType ELYTRA = new ItemType("minecraft:elytra");
    public static final ItemType EMERALD = new ItemType("minecraft:emerald");
    public static final ItemType EMERALD_BLOCK = new ItemType("minecraft:emerald_block");
    public static final ItemType EMERALD_ORE = new ItemType("minecraft:emerald_ore");
    public static final ItemType ENCHANTED_BOOK = new ItemType("minecraft:enchanted_book");
    public static final ItemType ENCHANTED_GOLDEN_APPLE = new ItemType("minecraft:enchanted_golden_apple");
    public static final ItemType ENCHANTING_TABLE = new ItemType("minecraft:enchanting_table");
    public static final ItemType END_CRYSTAL = new ItemType("minecraft:end_crystal");
    public static final ItemType END_PORTAL_FRAME = new ItemType("minecraft:end_portal_frame");
    public static final ItemType END_ROD = new ItemType("minecraft:end_rod");
    public static final ItemType END_STONE = new ItemType("minecraft:end_stone");
    public static final ItemType END_STONE_BRICKS = new ItemType("minecraft:end_stone_bricks");
    public static final ItemType ENDER_CHEST = new ItemType("minecraft:ender_chest");
    public static final ItemType ENDER_EYE = new ItemType("minecraft:ender_eye");
    public static final ItemType ENDER_PEARL = new ItemType("minecraft:ender_pearl");
    public static final ItemType ENDERMAN_SPAWN_EGG = new ItemType("minecraft:enderman_spawn_egg");
    public static final ItemType ENDERMITE_SPAWN_EGG = new ItemType("minecraft:endermite_spawn_egg");
    public static final ItemType EVOCATION_ILLAGER_SPAWN_EGG = new ItemType("minecraft:evocation_illager_spawn_egg");
    public static final ItemType EXPERIENCE_BOTTLE = new ItemType("minecraft:experience_bottle");
    public static final ItemType FARMLAND = new ItemType("minecraft:farmland");
    public static final ItemType FEATHER = new ItemType("minecraft:feather");
    public static final ItemType FERMENTED_SPIDER_EYE = new ItemType("minecraft:fermented_spider_eye");
    public static final ItemType FERN = new ItemType("minecraft:fern");
    public static final ItemType FILLED_MAP = new ItemType("minecraft:filled_map");
    public static final ItemType FIRE_CHARGE = new ItemType("minecraft:fire_charge");
    public static final ItemType FIRE_CORAL = new ItemType("minecraft:fire_coral");
    public static final ItemType FIRE_CORAL_BLOCK = new ItemType("minecraft:fire_coral_block");
    public static final ItemType FIRE_CORAL_FAN = new ItemType("minecraft:fire_coral_fan");
    public static final ItemType FIREWORK_ROCKET = new ItemType("minecraft:firework_rocket");
    public static final ItemType FIREWORK_STAR = new ItemType("minecraft:firework_star");
    public static final ItemType FISHING_ROD = new ItemType("minecraft:fishing_rod");
    public static final ItemType FLINT = new ItemType("minecraft:flint");
    public static final ItemType FLINT_AND_STEEL = new ItemType("minecraft:flint_and_steel");
    public static final ItemType FLOWER_POT = new ItemType("minecraft:flower_pot");
    public static final ItemType FURNACE = new ItemType("minecraft:furnace");
    public static final ItemType FURNACE_MINECART = new ItemType("minecraft:furnace_minecart");
    public static final ItemType GHAST_SPAWN_EGG = new ItemType("minecraft:ghast_spawn_egg");
    public static final ItemType GHAST_TEAR = new ItemType("minecraft:ghast_tear");
    public static final ItemType GLASS = new ItemType("minecraft:glass");
    public static final ItemType GLASS_BOTTLE = new ItemType("minecraft:glass_bottle");
    public static final ItemType GLASS_PANE = new ItemType("minecraft:glass_pane");
    public static final ItemType GLISTERING_MELON_SLICE = new ItemType("minecraft:glistering_melon_slice");
    public static final ItemType GLOWSTONE = new ItemType("minecraft:glowstone");
    public static final ItemType GLOWSTONE_DUST = new ItemType("minecraft:glowstone_dust");
    public static final ItemType GOLD_BLOCK = new ItemType("minecraft:gold_block");
    public static final ItemType GOLD_INGOT = new ItemType("minecraft:gold_ingot");
    public static final ItemType GOLD_NUGGET = new ItemType("minecraft:gold_nugget");
    public static final ItemType GOLD_ORE = new ItemType("minecraft:gold_ore");
    public static final ItemType GOLDEN_APPLE = new ItemType("minecraft:golden_apple");
    public static final ItemType GOLDEN_AXE = new ItemType("minecraft:golden_axe");
    public static final ItemType GOLDEN_BOOTS = new ItemType("minecraft:golden_boots");
    public static final ItemType GOLDEN_CARROT = new ItemType("minecraft:golden_carrot");
    public static final ItemType GOLDEN_CHESTPLATE = new ItemType("minecraft:golden_chestplate");
    public static final ItemType GOLDEN_HELMET = new ItemType("minecraft:golden_helmet");
    public static final ItemType GOLDEN_HOE = new ItemType("minecraft:golden_hoe");
    public static final ItemType GOLDEN_HORSE_ARMOR = new ItemType("minecraft:golden_horse_armor");
    public static final ItemType GOLDEN_LEGGINGS = new ItemType("minecraft:golden_leggings");
    public static final ItemType GOLDEN_PICKAXE = new ItemType("minecraft:golden_pickaxe");
    public static final ItemType GOLDEN_SHOVEL = new ItemType("minecraft:golden_shovel");
    public static final ItemType GOLDEN_SWORD = new ItemType("minecraft:golden_sword");
    public static final ItemType GRANITE = new ItemType("minecraft:granite");
    public static final ItemType GRASS = new ItemType("minecraft:grass");
    public static final ItemType GRASS_BLOCK = new ItemType("minecraft:grass_block");
    public static final ItemType GRASS_PATH = new ItemType("minecraft:grass_path");
    public static final ItemType GRAVEL = new ItemType("minecraft:gravel");
    public static final ItemType GRAY_BANNER = new ItemType("minecraft:gray_banner");
    public static final ItemType GRAY_CARPET = new ItemType("minecraft:gray_carpet");
    public static final ItemType GRAY_CONCRETE = new ItemType("minecraft:gray_concrete");
    public static final ItemType GRAY_CONCRETE_POWDER = new ItemType("minecraft:gray_concrete_powder");
    public static final ItemType GRAY_DYE = new ItemType("minecraft:gray_dye");
    public static final ItemType GRAY_GLAZED_TERRACOTTA = new ItemType("minecraft:gray_glazed_terracotta");
    public static final ItemType GRAY_STAINED_GLASS = new ItemType("minecraft:gray_stained_glass");
    public static final ItemType GRAY_STAINED_GLASS_PANE = new ItemType("minecraft:gray_stained_glass_pane");
    public static final ItemType GRAY_TERRACOTTA = new ItemType("minecraft:gray_terracotta");
    public static final ItemType GRAY_WOOL = new ItemType("minecraft:gray_wool");
    public static final ItemType GREEN_BANNER = new ItemType("minecraft:green_banner");
    public static final ItemType GREEN_CARPET = new ItemType("minecraft:green_carpet");
    public static final ItemType GREEN_CONCRETE = new ItemType("minecraft:green_concrete");
    public static final ItemType GREEN_CONCRETE_POWDER = new ItemType("minecraft:green_concrete_powder");
    public static final ItemType GREEN_GLAZED_TERRACOTTA = new ItemType("minecraft:green_glazed_terracotta");
    public static final ItemType GREEN_STAINED_GLASS = new ItemType("minecraft:green_stained_glass");
    public static final ItemType GREEN_STAINED_GLASS_PANE = new ItemType("minecraft:green_stained_glass_pane");
    public static final ItemType GREEN_TERRACOTTA = new ItemType("minecraft:green_terracotta");
    public static final ItemType GREEN_WOOL = new ItemType("minecraft:green_wool");
    public static final ItemType GUARDIAN_SPAWN_EGG = new ItemType("minecraft:guardian_spawn_egg");
    public static final ItemType GUNPOWDER = new ItemType("minecraft:gunpowder");
    public static final ItemType HAY_BLOCK = new ItemType("minecraft:hay_block");
    public static final ItemType HEART_OF_THE_SEA = new ItemType("minecraft:heart_of_the_sea");
    public static final ItemType HEAVY_WEIGHTED_PRESSURE_PLATE = new ItemType("minecraft:heavy_weighted_pressure_plate");
    public static final ItemType HOPPER = new ItemType("minecraft:hopper");
    public static final ItemType HOPPER_MINECART = new ItemType("minecraft:hopper_minecart");
    public static final ItemType HORN_CORAL = new ItemType("minecraft:horn_coral");
    public static final ItemType HORN_CORAL_BLOCK = new ItemType("minecraft:horn_coral_block");
    public static final ItemType HORN_CORAL_FAN = new ItemType("minecraft:horn_coral_fan");
    public static final ItemType HORSE_SPAWN_EGG = new ItemType("minecraft:horse_spawn_egg");
    public static final ItemType HUSK_SPAWN_EGG = new ItemType("minecraft:husk_spawn_egg");
    public static final ItemType ICE = new ItemType("minecraft:ice");
    public static final ItemType INFESTED_CHISELED_STONE_BRICKS = new ItemType("minecraft:infested_chiseled_stone_bricks");
    public static final ItemType INFESTED_COBBLESTONE = new ItemType("minecraft:infested_cobblestone");
    public static final ItemType INFESTED_CRACKED_STONE_BRICKS = new ItemType("minecraft:infested_cracked_stone_bricks");
    public static final ItemType INFESTED_MOSSY_STONE_BRICKS = new ItemType("minecraft:infested_mossy_stone_bricks");
    public static final ItemType INFESTED_STONE = new ItemType("minecraft:infested_stone");
    public static final ItemType INFESTED_STONE_BRICKS = new ItemType("minecraft:infested_stone_bricks");
    public static final ItemType INK_SAC = new ItemType("minecraft:ink_sac");
    public static final ItemType IRON_AXE = new ItemType("minecraft:iron_axe");
    public static final ItemType IRON_BARS = new ItemType("minecraft:iron_bars");
    public static final ItemType IRON_BLOCK = new ItemType("minecraft:iron_block");
    public static final ItemType IRON_BOOTS = new ItemType("minecraft:iron_boots");
    public static final ItemType IRON_CHESTPLATE = new ItemType("minecraft:iron_chestplate");
    public static final ItemType IRON_HELMET = new ItemType("minecraft:iron_helmet");
    public static final ItemType IRON_HOE = new ItemType("minecraft:iron_hoe");
    public static final ItemType IRON_HORSE_ARMOR = new ItemType("minecraft:iron_horse_armor");
    public static final ItemType IRON_INGOT = new ItemType("minecraft:iron_ingot");
    public static final ItemType IRON_LEGGINGS = new ItemType("minecraft:iron_leggings");
    public static final ItemType IRON_NUGGET = new ItemType("minecraft:iron_nugget");
    public static final ItemType IRON_ORE = new ItemType("minecraft:iron_ore");
    public static final ItemType IRON_PICKAXE = new ItemType("minecraft:iron_pickaxe");
    public static final ItemType IRON_SHOVEL = new ItemType("minecraft:iron_shovel");
    public static final ItemType IRON_SWORD = new ItemType("minecraft:iron_sword");
    public static final ItemType IRON_TRAPDOOR = new ItemType("minecraft:iron_trapdoor");
    public static final ItemType ITEM_FRAME = new ItemType("minecraft:item_frame");
    public static final ItemType JACK_O_LANTERN = new ItemType("minecraft:jack_o_lantern");
    public static final ItemType JUKEBOX = new ItemType("minecraft:jukebox");
    public static final ItemType JUNGLE_BARK = new ItemType("minecraft:jungle_bark");
    public static final ItemType JUNGLE_BOAT = new ItemType("minecraft:jungle_boat");
    public static final ItemType JUNGLE_BUTTON = new ItemType("minecraft:jungle_button");
    public static final ItemType JUNGLE_FENCE = new ItemType("minecraft:jungle_fence");
    public static final ItemType JUNGLE_FENCE_GATE = new ItemType("minecraft:jungle_fence_gate");
    public static final ItemType JUNGLE_LEAVES = new ItemType("minecraft:jungle_leaves");
    public static final ItemType JUNGLE_LOG = new ItemType("minecraft:jungle_log");
    public static final ItemType JUNGLE_PLANKS = new ItemType("minecraft:jungle_planks");
    public static final ItemType JUNGLE_PRESSURE_PLATE = new ItemType("minecraft:jungle_pressure_plate");
    public static final ItemType JUNGLE_SAPLING = new ItemType("minecraft:jungle_sapling");
    public static final ItemType JUNGLE_SLAB = new ItemType("minecraft:jungle_slab");
    public static final ItemType JUNGLE_STAIRS = new ItemType("minecraft:jungle_stairs");
    public static final ItemType JUNGLE_TRAPDOOR = new ItemType("minecraft:jungle_trapdoor");
    public static final ItemType KELP = new ItemType("minecraft:kelp");
    public static final ItemType KNOWLEDGE_BOOK = new ItemType("minecraft:knowledge_book");
    public static final ItemType LADDER = new ItemType("minecraft:ladder");
    public static final ItemType LAPIS_BLOCK = new ItemType("minecraft:lapis_block");
    public static final ItemType LAPIS_LAZULI = new ItemType("minecraft:lapis_lazuli");
    public static final ItemType LAPIS_ORE = new ItemType("minecraft:lapis_ore");
    public static final ItemType LAVA_BUCKET = new ItemType("minecraft:lava_bucket");
    public static final ItemType LEAD = new ItemType("minecraft:lead");
    public static final ItemType LEATHER = new ItemType("minecraft:leather");
    public static final ItemType LEATHER_BOOTS = new ItemType("minecraft:leather_boots");
    public static final ItemType LEATHER_CHESTPLATE = new ItemType("minecraft:leather_chestplate");
    public static final ItemType LEATHER_HELMET = new ItemType("minecraft:leather_helmet");
    public static final ItemType LEATHER_LEGGINGS = new ItemType("minecraft:leather_leggings");
    public static final ItemType LEVER = new ItemType("minecraft:lever");
    public static final ItemType LIGHT_BLUE_BANNER = new ItemType("minecraft:light_blue_banner");
    public static final ItemType LIGHT_BLUE_CARPET = new ItemType("minecraft:light_blue_carpet");
    public static final ItemType LIGHT_BLUE_CONCRETE = new ItemType("minecraft:light_blue_concrete");
    public static final ItemType LIGHT_BLUE_CONCRETE_POWDER = new ItemType("minecraft:light_blue_concrete_powder");
    public static final ItemType LIGHT_BLUE_DYE = new ItemType("minecraft:light_blue_dye");
    public static final ItemType LIGHT_BLUE_GLAZED_TERRACOTTA = new ItemType("minecraft:light_blue_glazed_terracotta");
    public static final ItemType LIGHT_BLUE_STAINED_GLASS = new ItemType("minecraft:light_blue_stained_glass");
    public static final ItemType LIGHT_BLUE_STAINED_GLASS_PANE = new ItemType("minecraft:light_blue_stained_glass_pane");
    public static final ItemType LIGHT_BLUE_TERRACOTTA = new ItemType("minecraft:light_blue_terracotta");
    public static final ItemType LIGHT_BLUE_WOOL = new ItemType("minecraft:light_blue_wool");
    public static final ItemType LIGHT_GRAY_BANNER = new ItemType("minecraft:light_gray_banner");
    public static final ItemType LIGHT_GRAY_CARPET = new ItemType("minecraft:light_gray_carpet");
    public static final ItemType LIGHT_GRAY_CONCRETE = new ItemType("minecraft:light_gray_concrete");
    public static final ItemType LIGHT_GRAY_CONCRETE_POWDER = new ItemType("minecraft:light_gray_concrete_powder");
    public static final ItemType LIGHT_GRAY_DYE = new ItemType("minecraft:light_gray_dye");
    public static final ItemType LIGHT_GRAY_GLAZED_TERRACOTTA = new ItemType("minecraft:light_gray_glazed_terracotta");
    public static final ItemType LIGHT_GRAY_STAINED_GLASS = new ItemType("minecraft:light_gray_stained_glass");
    public static final ItemType LIGHT_GRAY_STAINED_GLASS_PANE = new ItemType("minecraft:light_gray_stained_glass_pane");
    public static final ItemType LIGHT_GRAY_TERRACOTTA = new ItemType("minecraft:light_gray_terracotta");
    public static final ItemType LIGHT_GRAY_WOOL = new ItemType("minecraft:light_gray_wool");
    public static final ItemType LIGHT_WEIGHTED_PRESSURE_PLATE = new ItemType("minecraft:light_weighted_pressure_plate");
    public static final ItemType LIME_BANNER = new ItemType("minecraft:lime_banner");
    public static final ItemType LIME_CARPET = new ItemType("minecraft:lime_carpet");
    public static final ItemType LIME_CONCRETE = new ItemType("minecraft:lime_concrete");
    public static final ItemType LIME_CONCRETE_POWDER = new ItemType("minecraft:lime_concrete_powder");
    public static final ItemType LIME_DYE = new ItemType("minecraft:lime_dye");
    public static final ItemType LIME_GLAZED_TERRACOTTA = new ItemType("minecraft:lime_glazed_terracotta");
    public static final ItemType LIME_STAINED_GLASS = new ItemType("minecraft:lime_stained_glass");
    public static final ItemType LIME_STAINED_GLASS_PANE = new ItemType("minecraft:lime_stained_glass_pane");
    public static final ItemType LIME_TERRACOTTA = new ItemType("minecraft:lime_terracotta");
    public static final ItemType LIME_WOOL = new ItemType("minecraft:lime_wool");
    public static final ItemType LINGERING_POTION = new ItemType("minecraft:lingering_potion");
    public static final ItemType LLAMA_SPAWN_EGG = new ItemType("minecraft:llama_spawn_egg");
    public static final ItemType MAGENTA_BANNER = new ItemType("minecraft:magenta_banner");
    public static final ItemType MAGENTA_CARPET = new ItemType("minecraft:magenta_carpet");
    public static final ItemType MAGENTA_CONCRETE = new ItemType("minecraft:magenta_concrete");
    public static final ItemType MAGENTA_CONCRETE_POWDER = new ItemType("minecraft:magenta_concrete_powder");
    public static final ItemType MAGENTA_DYE = new ItemType("minecraft:magenta_dye");
    public static final ItemType MAGENTA_GLAZED_TERRACOTTA = new ItemType("minecraft:magenta_glazed_terracotta");
    public static final ItemType MAGENTA_STAINED_GLASS = new ItemType("minecraft:magenta_stained_glass");
    public static final ItemType MAGENTA_STAINED_GLASS_PANE = new ItemType("minecraft:magenta_stained_glass_pane");
    public static final ItemType MAGENTA_TERRACOTTA = new ItemType("minecraft:magenta_terracotta");
    public static final ItemType MAGENTA_WOOL = new ItemType("minecraft:magenta_wool");
    public static final ItemType MAGMA_BLOCK = new ItemType("minecraft:magma_block");
    public static final ItemType MAGMA_CREAM = new ItemType("minecraft:magma_cream");
    public static final ItemType MAGMA_CUBE_SPAWN_EGG = new ItemType("minecraft:magma_cube_spawn_egg");
    public static final ItemType MAP = new ItemType("minecraft:map");
    public static final ItemType MELON = new ItemType("minecraft:melon");
    public static final ItemType MELON_SEEDS = new ItemType("minecraft:melon_seeds");
    public static final ItemType MELON_SLICE = new ItemType("minecraft:melon_slice");
    public static final ItemType MILK_BUCKET = new ItemType("minecraft:milk_bucket");
    public static final ItemType MINECART = new ItemType("minecraft:minecart");
    public static final ItemType MOB_SPAWNER = new ItemType("minecraft:mob_spawner");
    public static final ItemType MOOSHROOM_SPAWN_EGG = new ItemType("minecraft:mooshroom_spawn_egg");
    public static final ItemType MOSSY_COBBLESTONE = new ItemType("minecraft:mossy_cobblestone");
    public static final ItemType MOSSY_COBBLESTONE_WALL = new ItemType("minecraft:mossy_cobblestone_wall");
    public static final ItemType MOSSY_STONE_BRICKS = new ItemType("minecraft:mossy_stone_bricks");
    public static final ItemType MULE_SPAWN_EGG = new ItemType("minecraft:mule_spawn_egg");
    public static final ItemType MUSHROOM_STEM = new ItemType("minecraft:mushroom_stem");
    public static final ItemType MUSHROOM_STEW = new ItemType("minecraft:mushroom_stew");
    public static final ItemType MUSIC_DISC_11 = new ItemType("minecraft:music_disc_11");
    public static final ItemType MUSIC_DISC_13 = new ItemType("minecraft:music_disc_13");
    public static final ItemType MUSIC_DISC_BLOCKS = new ItemType("minecraft:music_disc_blocks");
    public static final ItemType MUSIC_DISC_CAT = new ItemType("minecraft:music_disc_cat");
    public static final ItemType MUSIC_DISC_CHIRP = new ItemType("minecraft:music_disc_chirp");
    public static final ItemType MUSIC_DISC_FAR = new ItemType("minecraft:music_disc_far");
    public static final ItemType MUSIC_DISC_MALL = new ItemType("minecraft:music_disc_mall");
    public static final ItemType MUSIC_DISC_MELLOHI = new ItemType("minecraft:music_disc_mellohi");
    public static final ItemType MUSIC_DISC_STAL = new ItemType("minecraft:music_disc_stal");
    public static final ItemType MUSIC_DISC_STRAD = new ItemType("minecraft:music_disc_strad");
    public static final ItemType MUSIC_DISC_WAIT = new ItemType("minecraft:music_disc_wait");
    public static final ItemType MUSIC_DISC_WARD = new ItemType("minecraft:music_disc_ward");
    public static final ItemType MUTTON = new ItemType("minecraft:mutton");
    public static final ItemType MYCELIUM = new ItemType("minecraft:mycelium");
    public static final ItemType NAME_TAG = new ItemType("minecraft:name_tag");
    public static final ItemType NAUTILUS_SHELL = new ItemType("minecraft:nautilus_shell");
    public static final ItemType NETHER_BRICK = new ItemType("minecraft:nether_brick");
    public static final ItemType NETHER_BRICK_FENCE = new ItemType("minecraft:nether_brick_fence");
    public static final ItemType NETHER_BRICK_SLAB = new ItemType("minecraft:nether_brick_slab");
    public static final ItemType NETHER_BRICK_STAIRS = new ItemType("minecraft:nether_brick_stairs");
    public static final ItemType NETHER_BRICKS = new ItemType("minecraft:nether_bricks");
    public static final ItemType NETHER_QUARTZ_ORE = new ItemType("minecraft:nether_quartz_ore");
    public static final ItemType NETHER_STAR = new ItemType("minecraft:nether_star");
    public static final ItemType NETHER_WART = new ItemType("minecraft:nether_wart");
    public static final ItemType NETHER_WART_BLOCK = new ItemType("minecraft:nether_wart_block");
    public static final ItemType NETHERRACK = new ItemType("minecraft:netherrack");
    public static final ItemType NOTE_BLOCK = new ItemType("minecraft:note_block");
    public static final ItemType OAK_BARK = new ItemType("minecraft:oak_bark");
    public static final ItemType OAK_BOAT = new ItemType("minecraft:oak_boat");
    public static final ItemType OAK_BUTTON = new ItemType("minecraft:oak_button");
    public static final ItemType OAK_FENCE = new ItemType("minecraft:oak_fence");
    public static final ItemType OAK_FENCE_GATE = new ItemType("minecraft:oak_fence_gate");
    public static final ItemType OAK_LEAVES = new ItemType("minecraft:oak_leaves");
    public static final ItemType OAK_LOG = new ItemType("minecraft:oak_log");
    public static final ItemType OAK_PLANKS = new ItemType("minecraft:oak_planks");
    public static final ItemType OAK_PRESSURE_PLATE = new ItemType("minecraft:oak_pressure_plate");
    public static final ItemType OAK_SAPLING = new ItemType("minecraft:oak_sapling");
    public static final ItemType OAK_SLAB = new ItemType("minecraft:oak_slab");
    public static final ItemType OAK_STAIRS = new ItemType("minecraft:oak_stairs");
    public static final ItemType OAK_TRAPDOOR = new ItemType("minecraft:oak_trapdoor");
    public static final ItemType OBSERVER = new ItemType("minecraft:observer");
    public static final ItemType OBSIDIAN = new ItemType("minecraft:obsidian");
    public static final ItemType OCELOT_SPAWN_EGG = new ItemType("minecraft:ocelot_spawn_egg");
    public static final ItemType ORANGE_BANNER = new ItemType("minecraft:orange_banner");
    public static final ItemType ORANGE_CARPET = new ItemType("minecraft:orange_carpet");
    public static final ItemType ORANGE_CONCRETE = new ItemType("minecraft:orange_concrete");
    public static final ItemType ORANGE_CONCRETE_POWDER = new ItemType("minecraft:orange_concrete_powder");
    public static final ItemType ORANGE_DYE = new ItemType("minecraft:orange_dye");
    public static final ItemType ORANGE_GLAZED_TERRACOTTA = new ItemType("minecraft:orange_glazed_terracotta");
    public static final ItemType ORANGE_STAINED_GLASS = new ItemType("minecraft:orange_stained_glass");
    public static final ItemType ORANGE_STAINED_GLASS_PANE = new ItemType("minecraft:orange_stained_glass_pane");
    public static final ItemType ORANGE_TERRACOTTA = new ItemType("minecraft:orange_terracotta");
    public static final ItemType ORANGE_TULIP = new ItemType("minecraft:orange_tulip");
    public static final ItemType ORANGE_WOOL = new ItemType("minecraft:orange_wool");
    public static final ItemType OXEYE_DAISY = new ItemType("minecraft:oxeye_daisy");
    public static final ItemType PACKED_ICE = new ItemType("minecraft:packed_ice");
    public static final ItemType PAINTING = new ItemType("minecraft:painting");
    public static final ItemType PAPER = new ItemType("minecraft:paper");
    public static final ItemType PARROT_SPAWN_EGG = new ItemType("minecraft:parrot_spawn_egg");
    public static final ItemType PETRIFIED_OAK_SLAB = new ItemType("minecraft:petrified_oak_slab");
    public static final ItemType PHANTOM_MEMBRANE = new ItemType("minecraft:phantom_membrane");
    public static final ItemType PHANTOM_SPAWN_EGG = new ItemType("minecraft:phantom_spawn_egg");
    public static final ItemType PIG_SPAWN_EGG = new ItemType("minecraft:pig_spawn_egg");
    public static final ItemType PINK_BANNER = new ItemType("minecraft:pink_banner");
    public static final ItemType PINK_CARPET = new ItemType("minecraft:pink_carpet");
    public static final ItemType PINK_CONCRETE = new ItemType("minecraft:pink_concrete");
    public static final ItemType PINK_CONCRETE_POWDER = new ItemType("minecraft:pink_concrete_powder");
    public static final ItemType PINK_DYE = new ItemType("minecraft:pink_dye");
    public static final ItemType PINK_GLAZED_TERRACOTTA = new ItemType("minecraft:pink_glazed_terracotta");
    public static final ItemType PINK_STAINED_GLASS = new ItemType("minecraft:pink_stained_glass");
    public static final ItemType PINK_STAINED_GLASS_PANE = new ItemType("minecraft:pink_stained_glass_pane");
    public static final ItemType PINK_TERRACOTTA = new ItemType("minecraft:pink_terracotta");
    public static final ItemType PINK_TULIP = new ItemType("minecraft:pink_tulip");
    public static final ItemType PINK_WOOL = new ItemType("minecraft:pink_wool");
    public static final ItemType PISTON = new ItemType("minecraft:piston");
    public static final ItemType PODZOL = new ItemType("minecraft:podzol");
    public static final ItemType POISONOUS_POTATO = new ItemType("minecraft:poisonous_potato");
    public static final ItemType POLAR_BEAR_SPAWN_EGG = new ItemType("minecraft:polar_bear_spawn_egg");
    public static final ItemType POLISHED_ANDESITE = new ItemType("minecraft:polished_andesite");
    public static final ItemType POLISHED_DIORITE = new ItemType("minecraft:polished_diorite");
    public static final ItemType POLISHED_GRANITE = new ItemType("minecraft:polished_granite");
    public static final ItemType POPPY = new ItemType("minecraft:poppy");
    public static final ItemType PORKCHOP = new ItemType("minecraft:porkchop");
    public static final ItemType POTATO = new ItemType("minecraft:potato");
    public static final ItemType POTION = new ItemType("minecraft:potion");
    public static final ItemType POWERED_RAIL = new ItemType("minecraft:powered_rail");
    public static final ItemType PRISMARINE = new ItemType("minecraft:prismarine");
    public static final ItemType PRISMARINE_BRICK_SLAB = new ItemType("minecraft:prismarine_brick_slab");
    public static final ItemType PRISMARINE_BRICK_STAIRS = new ItemType("minecraft:prismarine_brick_stairs");
    public static final ItemType PRISMARINE_BRICKS = new ItemType("minecraft:prismarine_bricks");
    public static final ItemType PRISMARINE_CRYSTALS = new ItemType("minecraft:prismarine_crystals");
    public static final ItemType PRISMARINE_SHARD = new ItemType("minecraft:prismarine_shard");
    public static final ItemType PRISMARINE_SLAB = new ItemType("minecraft:prismarine_slab");
    public static final ItemType PRISMARINE_STAIRS = new ItemType("minecraft:prismarine_stairs");
    public static final ItemType PUFFERFISH = new ItemType("minecraft:pufferfish");
    public static final ItemType PUFFERFISH_BUCKET = new ItemType("minecraft:pufferfish_bucket");
    public static final ItemType PUFFERFISH_SPAWN_EGG = new ItemType("minecraft:pufferfish_spawn_egg");
    public static final ItemType PUMPKIN = new ItemType("minecraft:pumpkin");
    public static final ItemType PUMPKIN_PIE = new ItemType("minecraft:pumpkin_pie");
    public static final ItemType PUMPKIN_SEEDS = new ItemType("minecraft:pumpkin_seeds");
    public static final ItemType PURPLE_BANNER = new ItemType("minecraft:purple_banner");
    public static final ItemType PURPLE_CARPET = new ItemType("minecraft:purple_carpet");
    public static final ItemType PURPLE_CONCRETE = new ItemType("minecraft:purple_concrete");
    public static final ItemType PURPLE_CONCRETE_POWDER = new ItemType("minecraft:purple_concrete_powder");
    public static final ItemType PURPLE_DYE = new ItemType("minecraft:purple_dye");
    public static final ItemType PURPLE_GLAZED_TERRACOTTA = new ItemType("minecraft:purple_glazed_terracotta");
    public static final ItemType PURPLE_STAINED_GLASS = new ItemType("minecraft:purple_stained_glass");
    public static final ItemType PURPLE_STAINED_GLASS_PANE = new ItemType("minecraft:purple_stained_glass_pane");
    public static final ItemType PURPLE_TERRACOTTA = new ItemType("minecraft:purple_terracotta");
    public static final ItemType PURPLE_WOOL = new ItemType("minecraft:purple_wool");
    public static final ItemType PURPUR_BLOCK = new ItemType("minecraft:purpur_block");
    public static final ItemType PURPUR_PILLAR = new ItemType("minecraft:purpur_pillar");
    public static final ItemType PURPUR_SLAB = new ItemType("minecraft:purpur_slab");
    public static final ItemType PURPUR_STAIRS = new ItemType("minecraft:purpur_stairs");
    public static final ItemType QUARTZ = new ItemType("minecraft:quartz");
    public static final ItemType QUARTZ_BLOCK = new ItemType("minecraft:quartz_block");
    public static final ItemType QUARTZ_PILLAR = new ItemType("minecraft:quartz_pillar");
    public static final ItemType QUARTZ_SLAB = new ItemType("minecraft:quartz_slab");
    public static final ItemType QUARTZ_STAIRS = new ItemType("minecraft:quartz_stairs");
    public static final ItemType RABBIT = new ItemType("minecraft:rabbit");
    public static final ItemType RABBIT_FOOT = new ItemType("minecraft:rabbit_foot");
    public static final ItemType RABBIT_HIDE = new ItemType("minecraft:rabbit_hide");
    public static final ItemType RABBIT_SPAWN_EGG = new ItemType("minecraft:rabbit_spawn_egg");
    public static final ItemType RABBIT_STEW = new ItemType("minecraft:rabbit_stew");
    public static final ItemType RAIL = new ItemType("minecraft:rail");
    public static final ItemType RED_BANNER = new ItemType("minecraft:red_banner");
    public static final ItemType RED_CARPET = new ItemType("minecraft:red_carpet");
    public static final ItemType RED_CONCRETE = new ItemType("minecraft:red_concrete");
    public static final ItemType RED_CONCRETE_POWDER = new ItemType("minecraft:red_concrete_powder");
    public static final ItemType RED_GLAZED_TERRACOTTA = new ItemType("minecraft:red_glazed_terracotta");
    public static final ItemType RED_MUSHROOM = new ItemType("minecraft:red_mushroom");
    public static final ItemType RED_MUSHROOM_BLOCK = new ItemType("minecraft:red_mushroom_block");
    public static final ItemType RED_NETHER_BRICKS = new ItemType("minecraft:red_nether_bricks");
    public static final ItemType RED_SAND = new ItemType("minecraft:red_sand");
    public static final ItemType RED_SANDSTONE = new ItemType("minecraft:red_sandstone");
    public static final ItemType RED_SANDSTONE_SLAB = new ItemType("minecraft:red_sandstone_slab");
    public static final ItemType RED_SANDSTONE_STAIRS = new ItemType("minecraft:red_sandstone_stairs");
    public static final ItemType RED_STAINED_GLASS = new ItemType("minecraft:red_stained_glass");
    public static final ItemType RED_STAINED_GLASS_PANE = new ItemType("minecraft:red_stained_glass_pane");
    public static final ItemType RED_TERRACOTTA = new ItemType("minecraft:red_terracotta");
    public static final ItemType RED_TULIP = new ItemType("minecraft:red_tulip");
    public static final ItemType RED_WOOL = new ItemType("minecraft:red_wool");
    public static final ItemType REDSTONE = new ItemType("minecraft:redstone");
    public static final ItemType REDSTONE_BLOCK = new ItemType("minecraft:redstone_block");
    public static final ItemType REDSTONE_LAMP = new ItemType("minecraft:redstone_lamp");
    public static final ItemType REDSTONE_ORE = new ItemType("minecraft:redstone_ore");
    public static final ItemType REPEATER = new ItemType("minecraft:repeater");
    public static final ItemType ROSE_RED = new ItemType("minecraft:rose_red");
    public static final ItemType ROTTEN_FLESH = new ItemType("minecraft:rotten_flesh");
    public static final ItemType SADDLE = new ItemType("minecraft:saddle");
    public static final ItemType SALMON = new ItemType("minecraft:salmon");
    public static final ItemType SALMON_BUCKET = new ItemType("minecraft:salmon_bucket");
    public static final ItemType SALMON_SPAWN_EGG = new ItemType("minecraft:salmon_spawn_egg");
    public static final ItemType SAND = new ItemType("minecraft:sand");
    public static final ItemType SANDSTONE = new ItemType("minecraft:sandstone");
    public static final ItemType SANDSTONE_SLAB = new ItemType("minecraft:sandstone_slab");
    public static final ItemType SANDSTONE_STAIRS = new ItemType("minecraft:sandstone_stairs");
    public static final ItemType SCUTE = new ItemType("minecraft:scute");
    public static final ItemType SEA_LANTERN = new ItemType("minecraft:sea_lantern");
    public static final ItemType SEA_PICKLE = new ItemType("minecraft:sea_pickle");
    public static final ItemType SEAGRASS = new ItemType("minecraft:seagrass");
    public static final ItemType SHEARS = new ItemType("minecraft:shears");
    public static final ItemType SHEEP_SPAWN_EGG = new ItemType("minecraft:sheep_spawn_egg");
    public static final ItemType SHIELD = new ItemType("minecraft:shield");
    public static final ItemType SHULKER_SHELL = new ItemType("minecraft:shulker_shell");
    public static final ItemType SHULKER_SPAWN_EGG = new ItemType("minecraft:shulker_spawn_egg");
    public static final ItemType SIGN = new ItemType("minecraft:sign");
    public static final ItemType SILVERFISH_SPAWN_EGG = new ItemType("minecraft:silverfish_spawn_egg");
    public static final ItemType SKELETON_HORSE_SPAWN_EGG = new ItemType("minecraft:skeleton_horse_spawn_egg");
    public static final ItemType SKELETON_SPAWN_EGG = new ItemType("minecraft:skeleton_spawn_egg");
    public static final ItemType SLIME_BALL = new ItemType("minecraft:slime_ball");
    public static final ItemType SLIME_BLOCK = new ItemType("minecraft:slime_block");
    public static final ItemType SLIME_SPAWN_EGG = new ItemType("minecraft:slime_spawn_egg");
    public static final ItemType SMOOTH_QUARTZ = new ItemType("minecraft:smooth_quartz");
    public static final ItemType SMOOTH_RED_SANDSTONE = new ItemType("minecraft:smooth_red_sandstone");
    public static final ItemType SMOOTH_SANDSTONE = new ItemType("minecraft:smooth_sandstone");
    public static final ItemType SMOOTH_STONE = new ItemType("minecraft:smooth_stone");
    public static final ItemType SNOW = new ItemType("minecraft:snow");
    public static final ItemType SNOW_BLOCK = new ItemType("minecraft:snow_block");
    public static final ItemType SNOWBALL = new ItemType("minecraft:snowball");
    public static final ItemType SOUL_SAND = new ItemType("minecraft:soul_sand");
    public static final ItemType SPECTRAL_ARROW = new ItemType("minecraft:spectral_arrow");
    public static final ItemType SPIDER_EYE = new ItemType("minecraft:spider_eye");
    public static final ItemType SPIDER_SPAWN_EGG = new ItemType("minecraft:spider_spawn_egg");
    public static final ItemType SPLASH_POTION = new ItemType("minecraft:splash_potion");
    public static final ItemType SPONGE = new ItemType("minecraft:sponge");
    public static final ItemType SPRUCE_BARK = new ItemType("minecraft:spruce_bark");
    public static final ItemType SPRUCE_BOAT = new ItemType("minecraft:spruce_boat");
    public static final ItemType SPRUCE_BUTTON = new ItemType("minecraft:spruce_button");
    public static final ItemType SPRUCE_FENCE = new ItemType("minecraft:spruce_fence");
    public static final ItemType SPRUCE_FENCE_GATE = new ItemType("minecraft:spruce_fence_gate");
    public static final ItemType SPRUCE_LEAVES = new ItemType("minecraft:spruce_leaves");
    public static final ItemType SPRUCE_LOG = new ItemType("minecraft:spruce_log");
    public static final ItemType SPRUCE_PLANKS = new ItemType("minecraft:spruce_planks");
    public static final ItemType SPRUCE_PRESSURE_PLATE = new ItemType("minecraft:spruce_pressure_plate");
    public static final ItemType SPRUCE_SAPLING = new ItemType("minecraft:spruce_sapling");
    public static final ItemType SPRUCE_SLAB = new ItemType("minecraft:spruce_slab");
    public static final ItemType SPRUCE_STAIRS = new ItemType("minecraft:spruce_stairs");
    public static final ItemType SPRUCE_TRAPDOOR = new ItemType("minecraft:spruce_trapdoor");
    public static final ItemType SQUID_SPAWN_EGG = new ItemType("minecraft:squid_spawn_egg");
    public static final ItemType STICK = new ItemType("minecraft:stick");
    public static final ItemType STICKY_PISTON = new ItemType("minecraft:sticky_piston");
    public static final ItemType STONE = new ItemType("minecraft:stone");
    public static final ItemType STONE_AXE = new ItemType("minecraft:stone_axe");
    public static final ItemType STONE_BRICK_SLAB = new ItemType("minecraft:stone_brick_slab");
    public static final ItemType STONE_BRICK_STAIRS = new ItemType("minecraft:stone_brick_stairs");
    public static final ItemType STONE_BRICKS = new ItemType("minecraft:stone_bricks");
    public static final ItemType STONE_BUTTON = new ItemType("minecraft:stone_button");
    public static final ItemType STONE_HOE = new ItemType("minecraft:stone_hoe");
    public static final ItemType STONE_PICKAXE = new ItemType("minecraft:stone_pickaxe");
    public static final ItemType STONE_PRESSURE_PLATE = new ItemType("minecraft:stone_pressure_plate");
    public static final ItemType STONE_SHOVEL = new ItemType("minecraft:stone_shovel");
    public static final ItemType STONE_SLAB = new ItemType("minecraft:stone_slab");
    public static final ItemType STONE_SWORD = new ItemType("minecraft:stone_sword");
    public static final ItemType STRAY_SPAWN_EGG = new ItemType("minecraft:stray_spawn_egg");
    public static final ItemType STRING = new ItemType("minecraft:string");
    public static final ItemType STRIPPED_ACACIA_LOG = new ItemType("minecraft:stripped_acacia_log");
    public static final ItemType STRIPPED_BIRCH_LOG = new ItemType("minecraft:stripped_birch_log");
    public static final ItemType STRIPPED_DARK_OAK_LOG = new ItemType("minecraft:stripped_dark_oak_log");
    public static final ItemType STRIPPED_JUNGLE_LOG = new ItemType("minecraft:stripped_jungle_log");
    public static final ItemType STRIPPED_OAK_LOG = new ItemType("minecraft:stripped_oak_log");
    public static final ItemType STRIPPED_SPRUCE_LOG = new ItemType("minecraft:stripped_spruce_log");
    public static final ItemType STRUCTURE_VOID = new ItemType("minecraft:structure_void");
    public static final ItemType SUGAR = new ItemType("minecraft:sugar");
    public static final ItemType SUGAR_CANE = new ItemType("minecraft:sugar_cane");
    public static final ItemType TERRACOTTA = new ItemType("minecraft:terracotta");
    public static final ItemType TIPPED_ARROW = new ItemType("minecraft:tipped_arrow");
    public static final ItemType TNT = new ItemType("minecraft:tnt");
    public static final ItemType TNT_MINECART = new ItemType("minecraft:tnt_minecart");
    public static final ItemType TOTEM_OF_UNDYING = new ItemType("minecraft:totem_of_undying");
    public static final ItemType TRAPPED_CHEST = new ItemType("minecraft:trapped_chest");
    public static final ItemType TRIDENT = new ItemType("minecraft:trident");
    public static final ItemType TRIPWIRE_HOOK = new ItemType("minecraft:tripwire_hook");
    public static final ItemType TROPICAL_FISH_SPAWN_EGG = new ItemType("minecraft:tropical_fish_spawn_egg");
    public static final ItemType TUBE_CORAL = new ItemType("minecraft:tube_coral");
    public static final ItemType TUBE_CORAL_BLOCK = new ItemType("minecraft:tube_coral_block");
    public static final ItemType TUBE_CORAL_FAN = new ItemType("minecraft:tube_coral_fan");
    public static final ItemType TURTLE_EGG = new ItemType("minecraft:turtle_egg");
    public static final ItemType TURTLE_HELMET = new ItemType("minecraft:turtle_helmet");
    public static final ItemType TURTLE_SPAWN_EGG = new ItemType("minecraft:turtle_spawn_egg");
    public static final ItemType VEX_SPAWN_EGG = new ItemType("minecraft:vex_spawn_egg");
    public static final ItemType VILLAGER_SPAWN_EGG = new ItemType("minecraft:villager_spawn_egg");
    public static final ItemType VINDICATION_ILLAGER_SPAWN_EGG = new ItemType("minecraft:vindication_illager_spawn_egg");
    public static final ItemType VINE = new ItemType("minecraft:vine");
    public static final ItemType WATER_BUCKET = new ItemType("minecraft:water_bucket");
    public static final ItemType WET_SPONGE = new ItemType("minecraft:wet_sponge");
    public static final ItemType WHEAT = new ItemType("minecraft:wheat");
    public static final ItemType WHEAT_SEEDS = new ItemType("minecraft:wheat_seeds");
    public static final ItemType WHITE_BANNER = new ItemType("minecraft:white_banner");
    public static final ItemType WHITE_CARPET = new ItemType("minecraft:white_carpet");
    public static final ItemType WHITE_CONCRETE = new ItemType("minecraft:white_concrete");
    public static final ItemType WHITE_CONCRETE_POWDER = new ItemType("minecraft:white_concrete_powder");
    public static final ItemType WHITE_GLAZED_TERRACOTTA = new ItemType("minecraft:white_glazed_terracotta");
    public static final ItemType WHITE_STAINED_GLASS = new ItemType("minecraft:white_stained_glass");
    public static final ItemType WHITE_STAINED_GLASS_PANE = new ItemType("minecraft:white_stained_glass_pane");
    public static final ItemType WHITE_TERRACOTTA = new ItemType("minecraft:white_terracotta");
    public static final ItemType WHITE_TULIP = new ItemType("minecraft:white_tulip");
    public static final ItemType WHITE_WOOL = new ItemType("minecraft:white_wool");
    public static final ItemType WITCH_SPAWN_EGG = new ItemType("minecraft:witch_spawn_egg");
    public static final ItemType WITHER_SKELETON_SPAWN_EGG = new ItemType("minecraft:wither_skeleton_spawn_egg");
    public static final ItemType WOLF_SPAWN_EGG = new ItemType("minecraft:wolf_spawn_egg");
    public static final ItemType WOODEN_AXE = new ItemType("minecraft:wooden_axe");
    public static final ItemType WOODEN_HOE = new ItemType("minecraft:wooden_hoe");
    public static final ItemType WOODEN_PICKAXE = new ItemType("minecraft:wooden_pickaxe");
    public static final ItemType WOODEN_SHOVEL = new ItemType("minecraft:wooden_shovel");
    public static final ItemType WOODEN_SWORD = new ItemType("minecraft:wooden_sword");
    public static final ItemType WRITABLE_BOOK = new ItemType("minecraft:writable_book");
    public static final ItemType WRITTEN_BOOK = new ItemType("minecraft:written_book");
    public static final ItemType YELLOW_BANNER = new ItemType("minecraft:yellow_banner");
    public static final ItemType YELLOW_CARPET = new ItemType("minecraft:yellow_carpet");
    public static final ItemType YELLOW_CONCRETE = new ItemType("minecraft:yellow_concrete");
    public static final ItemType YELLOW_CONCRETE_POWDER = new ItemType("minecraft:yellow_concrete_powder");
    public static final ItemType YELLOW_GLAZED_TERRACOTTA = new ItemType("minecraft:yellow_glazed_terracotta");
    public static final ItemType YELLOW_STAINED_GLASS = new ItemType("minecraft:yellow_stained_glass");
    public static final ItemType YELLOW_STAINED_GLASS_PANE = new ItemType("minecraft:yellow_stained_glass_pane");
    public static final ItemType YELLOW_TERRACOTTA = new ItemType("minecraft:yellow_terracotta");
    public static final ItemType YELLOW_WOOL = new ItemType("minecraft:yellow_wool");
    public static final ItemType ZOMBIE_HORSE_SPAWN_EGG = new ItemType("minecraft:zombie_horse_spawn_egg");
    public static final ItemType ZOMBIE_PIGMAN_SPAWN_EGG = new ItemType("minecraft:zombie_pigman_spawn_egg");
    public static final ItemType ZOMBIE_SPAWN_EGG = new ItemType("minecraft:zombie_spawn_egg");
    public static final ItemType ZOMBIE_VILLAGER_SPAWN_EGG = new ItemType("minecraft:zombie_villager_spawn_egg");

    private static final Map<String, ItemType> itemMapping = new HashMap<>();

    static {
        for (Field field : ItemTypes.class.getFields()) {
            if (field.getType() == ItemType.class) {
                try {
                    registerItem((ItemType) field.get(null));
                } catch (IllegalAccessException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public static void registerItem(ItemType itemType) {
        if (itemMapping.containsKey(itemType.getId()) && !itemType.getId().startsWith("minecraft:")) {
            throw new IllegalArgumentException("Existing item with this ID already registered");
        }

        itemMapping.put(itemType.getId(), itemType);
    }

    @Nullable
    public static ItemType getItemType(String id) {
        // If it has no namespace, assume minecraft.
        if (id != null && !id.contains(":")) {
            id = "minecraft:" + id;
        }
        return itemMapping.get(id);
    }

    public static Collection<ItemType> values() {
        return itemMapping.values();
    }
}
